<?php

use jkdevkit\API;
use jkdevkit\Helper;
use jkdevkit\Shell;
use jkdevkit\License_Manager;
use jkdevkit\Controls_Manager;
use jkdevkit\Fonts_Manager;

defined('ABSPATH') || exit;

if (!class_exists('jkdevkit')):

    /*
     *
     * JKDEVKIT
     * FRAMEWORK
     * VERSION
     * 1.1
     *
     * */
    class jkdevkit
    {

        /**
         * @var float
         */
        public $jkd_version = 1.1;

        /**
         * @var
         */
        public $slug;

        /**
         * @var
         */
        public $id;

        /**
         * @var
         */
        public $url;

        /**
         * @var
         */
        public $version;

        /**
         * @var
         */
        public $author;

        /**
         * @var
         */
        public $name;

        /**
         * @var
         */
        public $tabs_callback;

        /**
         * @var
         */
        public $tabs_manager;

        /**
         * @var
         */
        public $license_manager;

        /**
         * @var
         */
        public $reqext;

        /**
         * @var
         */
        public $templates_path;

        /**
         * @var bool
         */
        private static $activation = false;

        /**
         * @var
         */
        private static $activation_data;

        /**
         * @return float
         */
        public function getJkdVersion(): float
        {
            return $this->jkd_version;
        }

        /**
         * @param float $jkd_version
         */
        public function setJkdVersion(float $jkd_version): void
        {
            $this->jkd_version = $jkd_version;
        }

        /**
         * @return mixed
         */
        public function getSlug()
        {
            return $this->slug;
        }

        /**
         * @param mixed $slug
         */
        public function setSlug($slug): void
        {
            $this->slug = $slug;
        }

        /**
         * @return mixed
         */
        public function getId()
        {
            return $this->id;
        }

        /**
         * @param mixed $id
         */
        public function setId($id): void
        {
            $this->id = $id;
        }

        /**
         * @return mixed
         */
        public function getUrl()
        {
            return $this->url;
        }

        /**
         * @param mixed $url
         */
        public function setUrl($url): void
        {
            $this->url = $url;
        }

        /**
         * @return mixed
         */
        public function getVersion()
        {
            return $this->version;
        }

        /**
         * @param mixed $version
         */
        public function setVersion($version): void
        {
            $this->version = $version;
        }

        /**
         * @return mixed
         */
        public function getAuthor()
        {
            return $this->author;
        }

        /**
         * @param mixed $author
         */
        public function setAuthor($author): void
        {
            $this->author = $author;
        }

        /**
         * @return mixed
         */
        public function getName()
        {
            return $this->name;
        }

        /**
         * @param mixed $name
         */
        public function setName($name): void
        {
            $this->name = $name;
        }

        /**
         * @return mixed
         */
        public function getTabsCallback()
        {
            return $this->tabs_callback;
        }

        /**
         * @param mixed $tabs_callback
         */
        public function setTabsCallback($tabs_callback): void
        {
            $this->tabs_callback = $tabs_callback;
        }

        /**
         * @return mixed
         */
        public function getTabsManager()
        {
            return $this->tabs_manager;
        }

        /**
         * @param mixed $tabs_manager
         */
        public function setTabsManager($tabs_manager): void
        {
            $this->tabs_manager = $tabs_manager;
        }

        /**
         * @return mixed
         */
        public function getLicenseManager()
        {
            return $this->license_manager;
        }

        /**
         * @param mixed $license_manager
         */
        public function setLicenseManager($license_manager): void
        {
            $this->license_manager = $license_manager;
        }

        /**
         * @return mixed
         */
        public function getReqext()
        {
            return $this->reqext;
        }

        /**
         * @param mixed $reqext
         */
        public function setReqext($reqext): void
        {
            $this->reqext = $reqext;
        }

        /**
         * @return mixed
         */
        public function getTemplatesPath()
        {
            return $this->templates_path;
        }

        /**
         * @param mixed $templates_path
         */
        public function setTemplatesPath($templates_path): void
        {
            $this->templates_path = $templates_path;
        }

        /**
         * @return bool
         */
        public static function isActivation(): bool
        {
            return self::$activation;
        }

        /**
         * @param bool $activation
         */
        public static function setActivation(bool $activation): void
        {
            self::$activation = $activation;
        }

        /**
         * @return mixed
         */
        public static function getActivationData()
        {
            return self::$activation_data;
        }

        /**
         * @param mixed $activation_data
         */
        public static function setActivationData($activation_data): void
        {
            self::$activation_data = $activation_data;
        }

        /**
         * @param $args
         *
         * @throws \Exception
         */
        public function __construct($args)
        {

            /* include modules */
            require_once dirname(__FILE__) . '/modules/entry.php';

            /* setup slug */
            if (!empty($args['slug'])):

                $this->setSlug($args['slug']);

            endif;

            /* setup name */
            if (!empty($args['name'])):

                $this->setName($args['name']);

            endif;

            /* setup id */
            if (!empty($args['id'])):

                $this->setId($args['id']);

            endif;

            /* setup url */
            if (!empty($args['url'])):

                $this->setUrl($args['url']);

            endif;

            /* setup author */
            if (!empty($args['author'])):

                $this->setAuthor($args['author']);

            endif;

            /* setup version */
            if (!empty($args['version'])):

                $this->setVersion($args['version']);

            endif;

            /* setup tabs callback */
            if (!empty($args['tabs_callback'])):

                $this->setTabsCallback($args['tabs_callback']);

            endif;

            /* setup required extensions */
            if (!empty($args['reqext'])):

                $this->setReqext($args['reqext']);

            endif;

            /* setup custom templates path */
            if (!empty($args['templates_path'])):

                $this->setTemplatesPath($args['templates_path']);

            endif;

            /* init */
            $this->init();

        }

        /**
         * @return void
         * @throws \Exception
         */
        public function init()
        {

            /* set license manager */
            $this->setLicenseManager(new \jkdevkit\License_Manager($this));

            /* set tabs manager */
            $this->setTabsManager(new \jkdevkit\Tabs_Manager($this));

            /* enqueue admin styles */
            add_action('admin_init', [$this, 'enqueue_admin_styles']);

            /* enqueue admin scripts */
            add_action('admin_enqueue_scripts', [$this, 'enqueue_admin_scripts']);

            /* mime types */
            add_filter('upload_mimes', [$this, 'mime_types']);

        }

        /**
         * @return void
         */
        public function enqueue_admin_styles()
        {

            /* enqueue tippy */
            wp_enqueue_style('jkd-tippy', $this->url . 'jkdevkit/assets/css/lib/tippy.min.css');

            /* enqueue remix icons */
            wp_enqueue_style('jkd-remix-icons', $this->url . 'jkdevkit/assets/css/lib/remixicon.min.css');

            /* enqueue jkdevkit styles */
            wp_enqueue_style('jkdevkit', $this->url . 'jkdevkit/assets/css/jkdevkit.min.css');

        }

        /**
         * @return void
         */
        public function enqueue_admin_scripts()
        {

            /* define wp global var */
            global $wp;

            /* (LIB) enqueue popper scripts */
            wp_enqueue_script('jkd-popper', $this->url . 'jkdevkit/assets/js/lib/popper.min.js', array('jquery'), $this->version);

            /* (LIB) enqueue tippy scripts */
            wp_enqueue_script('jkd-tippy', $this->url . 'jkdevkit/assets/js/lib/tippy.min.js', array('jquery'), $this->version);

            /* (LIB) enqueue jquery-cookie scripts */
            wp_enqueue_script('jkd-cookie', $this->url . 'jkdevkit/assets/js/lib/jquery-cookie.min.js', array('jquery'), $this->version);

            /* enqueue jkdevkit scripts */
            wp_enqueue_script('jkdevkit', $this->url . 'jkdevkit/assets/js/jkdevkit.min.js', array('jquery'), $this->version);

            /* enqueue settings scripts */
            wp_enqueue_script('jkd-settings', $this->url . 'jkdevkit/assets/js/settings.min.js', array('jquery'), $this->version);

            /* enqueue fonts scripts */
            wp_enqueue_script('jkd-fonts', $this->url . 'jkdevkit/assets/js/fonts.min.js', array('jquery'), $this->version);

            /* localize jkdevkit object for jkdevkit */
            wp_localize_script('jkdevkit', 'jkdevkit', array(
                'ajaxurl' => admin_url() . '/admin-ajax.php',
                'slug' => $this->slug,
                'item_id' => $this->id,
                'hostname' => esc_url(home_url($wp->request)),
                'author' => $this->author,
            ));

            /* localize i18 strings to jkd-settings */
            wp_localize_script('jkdevkit', 'i18', array(
                'empty_string' => esc_html__('String cannot be empty', 'qreatix'),
                'short_string' => esc_html__('String must be longer than 3 characters', 'qreatix'),
                'long_string' => esc_html__('String length exceeds 20 characters', 'qreatix'),
                'illegal_chars' => esc_html__('String contains spaces or illegal characters', 'qreatix'),
            ));

        }

        /**
         * @param $mimes
         *
         * @return mixed
         */
        public function mime_types($mimes)
        {

            /* json */
            $mimes['json'] = 'application/json';

            /* added otf to current mimes array */
            $mimes['otf'] = 'font/otf';

            /* added ttf to current mimes array */
            $mimes['ttf'] = 'font/ttf';

            /* added svg to current mimes array */
            $mimes['svg'] = 'image/svg+xml';

            /* added eot to current mimes array */
            $mimes['eot'] = 'application/x-font-eot';

            /* added woff to current mimes array */
            $mimes['woff'] = 'application/x-font-woff';

            /* added woff2 to current mimes array */
            $mimes['woff2'] = 'application/x-font-woff2';

            /* return types */
            return $mimes;

        }

        /**
         * @throws \Exception
         */
        public function shell($args)
        {

            new Shell($args, $this);

        }

    }

endif;
