<?php

namespace jkdevkit;

defined('ABSPATH') || exit;

class Controls_Manager extends \jkdevkit
{

    /**
     * @var null
     */
    private static $_instance = null;

    /**
     * @return \jkdevkit\Controls_Manager|null
     */
    public static function instance()
    {

        if (is_null(self::$_instance)) :

            self::$_instance = new self();

        endif;

        return self::$_instance;

    }

    /**
     *
     */
    public function __construct()
    {

        /* init ajax */
        $this->init_ajax();

    }

    /**
     * @return void
     */
    public function init_ajax()
    {

        /* ajax reset settings handler */
        add_action('wp_ajax_nopriv_jkd_reset_settings_handler', [$this, 'reset_settings']);
        add_action('wp_ajax_jkd_reset_settings_handler', [$this, 'reset_settings']);

        /* ajax import settings handler */
        add_action('wp_ajax_nopriv_jkd_import_settings_handler', [$this, 'import_settings']);
        add_action('wp_ajax_jkd_import_settings_handler', [$this, 'import_settings']);

        /* ajax export settings handler */
        add_action('wp_ajax_nopriv_jkd_export_settings_handler', [$this, 'export_settings']);
        add_action('wp_ajax_jkd_export_settings_handler', [$this, 'export_settings']);

        /* ajax apply setting handler */
        add_action('wp_ajax_nopriv_jkd_apply_setting_handler', [$this, 'apply_setting']);
        add_action('wp_ajax_jkd_apply_setting_handler', [$this, 'apply_setting']);

        /* ajax remove img setting handler */
        add_action('wp_ajax_nopriv_jkd_remove_img_setting_handler', [$this, 'remove_img_setting']);
        add_action('wp_ajax_jkd_remove_img_setting_handler', [$this, 'remove_img_setting']);

    }

    /**
     * @param $slug
     *
     * @return false|mixed|void
     */
    public static function get_setting($slug, $default = false)
    {

        if (!empty(get_option('jkd_setting_' . $slug))):

            return (get_option('jkd_setting_' . $slug));

        elseif (!empty(get_option('jkd_setting_' . $slug . '_default'))):

            return (get_option('jkd_setting_' . $slug . '_default'));

        else:

            return $default;

        endif;

    }

    /**
     * @return false|mixed|void
     */
    public static function get_all_settings()
    {

        return get_option('jkd_all_settings', array());

    }

    /**
     * @param $slug
     * @param $value
     *
     * @return void
     */
    public static function set_option($slug, $value)
    {

        if (!empty($slug)):

            update_option('jkd_option_' . $slug, $value, false);

        endif;

    }

    /**
     * @param $slug
     * @param $default
     *
     * @return false|mixed|void
     */
    public static function get_option($slug, $default = false)
    {

        if (!empty($slug)):

            if (empty(get_option('jkd_option_' . $slug))):

                return $default;

            else:

                return get_option('jkd_option_' . $slug);

            endif;

        endif;

    }

    /**
     * @param $slug
     * @param $value
     *
     * @return void
     */
    public static function set_setting($slug, $value)
    {

        if (!empty($slug)):

            /* update setting option */
            update_option('jkd_setting_' . $slug, $value, false);

            /* get all settings */
            $all_settings = get_option('jkd_all_settings', array());

            if (!in_array($slug, $all_settings)):

                $all_settings[$slug] = array(
                    'key' => $slug,
                    'value' => $value
                );

            endif;

            /* update all settings option */
            update_option('jkd_all_settings', $all_settings, false);

        endif;

    }

    /**
     * @param $slug
     *
     * @return false|mixed|void
     */
    public static function get_setting_default($slug)
    {

        if (!empty(get_option('jkd_setting_' . $slug . '_default'))):

            return (get_option('jkd_setting_' . $slug . '_default'));

        else:

            return false;

        endif;

    }

    /**
     * @param $slug
     * @param $value
     *
     * @return void
     */
    public static function set_setting_default($slug, $value)
    {

        if (!empty($slug)):

            update_option('jkd_setting_' . $slug . '_default', $value, false);

        endif;

    }

    /**
     * @param $slug
     *
     * @return void
     */
    public static function remove_setting($slug)
    {

        if (!empty($slug)):

            delete_option('jkd_setting_' . $slug);

        endif;

    }

    /**
     * @return void
     */
    public function reset_settings()
    {

        /* get all settings options (slugs only) */
        $settings = get_option('jkd_all_settings');

        /* check if settings is not empty */
        if (!empty($settings)):

            /* settings loop */
            foreach ($settings as $setting):

                /* remove setting by slug */
                self::remove_setting($setting['key']);

            endforeach;

            /* remove option with all settings slugs */
            delete_option('jkd_all_settings');

        endif;

        /* die */
        die();

    }

    /**
     * @return void
     */
    public function export_settings()
    {

        /* get all settings */
        $settings = get_option('jkd_all_settings');

        /* check if settings is not empty */
        if (!empty($settings)):

            /* empty dara array */
            $data = array();

            /* output settings array filling */
            foreach ($settings as $setting):

                /* set data item by settings slug (key) */
                $data[$setting['key']] = self::get_setting($setting['key']);

            endforeach;

            /* return output settings */
            print_r(json_encode(array(
                /* generate filename base on the current data */
                'filename' => $this->slug . "-export-" . date('d-m-y h:i:s') . ".json",
                /* data json */
                'data' => json_encode($data)
            )));

        endif;

        /* exit */
        die();

    }

    /**
     * @return void
     */
    public function import_settings()
    {

        /* if not empty entry file */
        if (!empty($_FILES["file"])):

            /* handler upload file */
            $movefile = wp_handle_upload($_FILES['file'], array('test_form' => false));

            /* get data from the entry file */
            $data = wp_remote_post($movefile['url']);

            /* check if data is not empty */
            if (!empty($data)):

                /* response body */
                $data = wp_remote_retrieve_body($data);

                /* decode json to associative array */
                $data = json_decode($data, true);

                /* check if data is not empty (after json decoding) */
                if (!empty($data)):

                    /* set values for each setting in entry file */
                    foreach ($data as $key => $setting):

                        /* set value by key */
                        self::set_setting($key, $setting);

                    endforeach;

                endif;

            endif;

        endif;

        /* exit */
        die();

    }

    /**
     * @return void
     */
    public function apply_setting()
    {

        /* get slug var */
        $slug = $_POST['slug'];

        /* get value var */
        $value = $_POST['value'];

        /* get type var (+additional trimming) */
        $type = trim((string)$_POST['type']);

        /* check if type var is "json" */
        if ($type === 'json'):

            /* replace all slashes */
            $value = str_replace('\\', '', $value);

            /* decode json string */
            $value = json_decode($value, true);

        endif;

        /* check if slug is not empty */
        if (!empty($slug)):

            /* set new setting value */
            self::set_setting($slug, $value);

        endif;

        /* exit */
        die();

    }

    /**
     * @return void
     */
    public function remove_img_setting()
    {

        /* get slug var */
        $slug = $_POST['slug'];

        /* set img setting to false */
        self::set_setting($slug, false);

        /* exit */
        die();

    }

    /**
     * @param array $settings
     *
     * @return void
     */
    public static function add_setting(array $settings = array())
    {

        if (!empty($settings)):

            /* type option */
            $type = !empty($settings['type']) ? $settings['type'] : '';

            /* slug option */
            $slug = !empty($settings['slug']) ? $settings['slug'] : '';

            /* label option */
            $label = !empty($settings['label']) ? $settings['label'] : '';

            /* placeholder option */
            $placeholder = !empty($settings['placeholder']) ? $settings['placeholder'] : '';

            /* description option */
            $description = !empty($settings['description']) ? $settings['description'] : '';

            /* default option */
            $default = !empty($settings['default']) ? $settings['default'] : false;

            /* options option :) */
            $options = !empty($settings['options']) ? $settings['options'] : array();

            /* sizes option */
            $sizes = !empty($settings['sizes']) ? $settings['sizes'] : array();

            /* to toggle option */
            $to_toggle = !empty($settings['to_toggle']) ? $settings['to_toggle'] : '';

            /* conditions option */
            $condition = !empty($settings['condition']) ? $settings['condition'] : '';

            /* step option */
            $step = !empty($settings['step']) ? $settings['step'] : 1;

            /* min option */
            $min = !empty($settings['min']) ? $settings['min'] : 0;

            /* max option */
            $max = !empty($settings['max']) ? $settings['max'] : 100;

            /* type option */
            $notice = !empty($settings['notice']) ? $settings['notice'] : array();

            /* cookie option */
            $cookie = !empty($settings['cookie']) ? $settings['cookie'] : '';

            /* ui option */
            $ui = !empty($settings['ui']) ? $settings['ui'] : '';

            /* color related option */
            $color_related = !empty($settings['color-related']) ? $settings['color-related'] : array();

            /* show toggle */
            $show = true;

            /* check if default value is not empty */
            if (!empty($default)):

                /* default option */
                $default_option = self::get_setting_default($slug);

                /* if default option is not default */
                if ($default_option !== $default):

                    /* set default value to setting */
                    self::set_setting_default($slug, $default);

                endif;

            endif;

            /* check if condition is not empty */
            if (!empty($condition)):

                /* conditions loop */
                foreach ($condition as $item):

                    /* setting key */
                    $setting_key = $item['key'];

                    /* setting value */
                    $setting_value = $item['value'];

                    /* check if key and value is not empty */
                    if (!empty($setting_key) && !empty($setting_value)):

                        /* setting default */
                        $setting_default = self::get_setting_default($setting_key);

                        /* setting option */
                        $setting_option = self::get_setting($setting_key, $setting_default);

                        /* setting value */
                        if (is_array($setting_value)):

                            /* setting option */
                            if (!in_array($setting_option, $setting_value)):

                                /* set show toggle to false */
                                $show = false;

                                break;

                            endif;

                        else:

                            /* check if setting option === setting value */
                            if ($setting_option !== $setting_value):

                                $show = false;

                                break;

                            endif;

                        endif;

                    endif;

                endforeach;

            endif;

            /* check if type var is not empty */
            if (!empty($type)):

                ?>

                <div class="setting-part <?php if (!$show): echo esc_attr('hidden'); endif; ?>"
                     id="<?php echo esc_attr('setting-' . $slug); ?>">

                    <?php if ($type !== 'divider'): ?>

                        <h6 class="setting-title">

                            <?php echo esc_html($label); ?>

                        </h6>

                        <p class="setting-description">

                            <?php echo esc_html($description); ?>

                        </p>

                    <?php

                    endif;

                    $value = self::get_setting($slug, $default);

                    if (!empty($cookie) && !empty($_COOKIE[$cookie])):

                        $value = $_COOKIE[$cookie];

                    endif;

                    if (!empty($condition)):

                        $condition = json_encode($condition);

                    endif;

                    if ($type === 'divider'):

                        ?>

                        <div class="jkd-settings-divider jkd-setting"
                            <?php if (!empty($condition)): ?>
                                data-condition="<?php echo esc_attr($condition); ?>"
                            <?php endif; ?>
                             data-setting-slug="<?php echo esc_attr($slug); ?>">

                            <hr class="before-hr">

                            <span>

                                <?php echo esc_html($label); ?>

                            </span>

                            <hr class="after-hr">

                        </div>

                    <?php

                    elseif ($type === 'text'):

                        ?>

                        <input type="text"
                               class="jkd-setting jkd-setting-text"
                            <?php if (!empty($condition)): ?>
                                data-condition="<?php echo esc_attr($condition); ?>"
                            <?php endif; ?>
                               data-setting-slug="<?php echo esc_attr($slug); ?>"
                               placeholder="<?php echo esc_attr($placeholder); ?>"
                               value="<?php echo esc_attr($value); ?>">

                    <?php

                    elseif ($type === 'password'):

                        ?>

                        <input type="password"
                               class="jkd-setting jkd-setting-password"
                            <?php if (!empty($condition)): ?>
                                data-condition="<?php echo esc_attr($condition); ?>"
                            <?php endif; ?>
                               data-setting-slug="<?php echo esc_attr($slug); ?>"
                               placeholder="<?php echo esc_attr($placeholder); ?>"
                               value="<?php echo esc_attr($value); ?>">

                    <?php

                    elseif ($type === 'url'):

                        ?>

                        <div class="input-shell">

                            <div class="input-icon">

                                <i class="ri-link-m"></i>

                            </div>

                            <input type="url"
                                   class="jkd-setting jkd-setting-url"
                                <?php if (!empty($condition)): ?>
                                    data-condition="<?php echo esc_attr($condition); ?>"
                                <?php endif; ?>
                                   data-setting-slug="<?php echo esc_attr($slug); ?>"
                                   placeholder="<?php echo esc_attr($placeholder); ?>"
                                   value="<?php echo esc_attr($value); ?>">

                            <div class="copy-button">

                                <i class="ri-file-copy-line"></i>

                            </div>

                        </div>

                    <?php

                    elseif ($type === 'html'):

                        ?>

                        <textarea class="jkd-setting jkd-setting-html"
                            <?php if (!empty($condition)): ?>
                                data-condition="<?php echo esc_attr($condition); ?>"
                            <?php endif; ?>
                               data-setting-slug="<?php echo esc_attr($slug); ?>"
                                  placeholder="<?php echo esc_attr($placeholder); ?>"><?php echo esc_html($value); ?></textarea>

                    <?php

                    elseif ($type === 'checkbox_group'):

                        if (!empty($options)):

                            ?>

                            <form class="jkd-setting jkd-setting-checkbox-group "
                                <?php if (!empty($condition)): ?>
                                    data-condition="<?php echo esc_attr($condition); ?>"
                                <?php endif; ?>
                                  data-setting-slug="<?php echo esc_attr($slug); ?>">

                                <?php foreach ($options as $key => $option): ?>

                                    <fieldset class="group-item">

                                        <input type="checkbox"
                                               class="jkd-setting-checkbox"
                                               id="<?php echo esc_attr($slug . '-' . $key); ?>"
                                               data-key="<?php echo esc_attr($key); ?>"
                                               value="<?php echo esc_attr($option); ?>"
                                               <?php if (!empty($value[$key])): ?>checked<?php endif; ?>>

                                        <label for="<?php echo esc_attr($slug . '-' . $key) ?>">

                                            <?php echo esc_html($option); ?>

                                        </label>

                                    </fieldset>

                                <?php endforeach; ?>

                            </form>

                        <?php

                        endif;

                    elseif ($type === 'radio_group'):

                        if (!empty($options)):

                            ?>

                            <form class="jkd-setting jkd-setting-radio-group "
                                <?php if (!empty($condition)): ?>
                                    data-condition="<?php echo esc_attr($condition); ?>"
                                <?php endif; ?>
                                  data-setting-slug="<?php echo esc_attr($slug); ?>">

                                <?php foreach ($options as $key => $option):
                                    ?>

                                    <fieldset class="group-item">

                                        <input type="radio"
                                               name="<?php echo esc_attr($slug); ?>"
                                               class="jkd-setting-radio"
                                               id="<?php echo esc_attr($slug . '-' . $key); ?>"
                                               data-key="<?php echo esc_attr($key); ?>"
                                               value="<?php echo esc_attr($option); ?>"
                                               <?php if ($value === $key): ?>checked<?php endif; ?>>

                                        <label for="<?php echo esc_attr($slug . '-' . $key) ?>">

                                            <?php echo esc_html($option); ?>

                                        </label>

                                    </fieldset>

                                <?php endforeach; ?>

                            </form>

                        <?php

                        endif;

                    elseif ($type === 'social'):

                        ?>

                        <div class="jkd-setting jkd-setting-social">

                            <ul class="social-list">

                            </ul>

                            <div class="add-button">

                                <i class="ri-add-line"></i>

                            </div>

                        </div>

                    <?php

                    elseif ($type === 'button_group'):

                        if (!empty($options)):

                            ?>

                            <div class="jkd-setting jkd-setting-button-group"
                                <?php if (!empty($condition)): ?>
                                    data-condition="<?php echo esc_attr($condition); ?>"
                                <?php endif; ?>
                                 data-setting-slug="<?php echo esc_attr($slug); ?>">

                                <?php foreach ($options as $key => $option): ?>

                                    <button class="jkd-button-item <?php if ($value === $key): ?>active<?php endif; ?>"
                                            id="<?php echo esc_attr($slug . '-' . $key); ?>"
                                            data-key="<?php echo esc_attr($key); ?>">

                                        <?php echo esc_html($option); ?>

                                    </button>

                                <?php endforeach; ?>

                            </div>

                        <?php

                        endif;

                    elseif ($type === 'select'):

                        if (!empty($options)):

                            ?>

                            <select class="jkd-setting jkd-setting-select"
                                <?php if (!empty($condition)): ?>
                                    data-condition="<?php echo esc_attr($condition); ?>"
                                <?php endif; ?>
                                    data-setting-slug="<?php echo esc_attr($slug); ?>">

                                <?php foreach ($options as $key => $option):

                                    ?>

                                    <option id="<?php echo esc_attr($slug . '-' . $key); ?>"
                                            data-key="<?php echo esc_attr($key); ?>"
                                            value="<?php echo esc_attr($option); ?>"
                                            <?php if ($value === $key): ?>selected<?php endif; ?>>

                                        <?php echo esc_html($option); ?>

                                    </option>

                                <?php endforeach; ?>

                            </select>

                        <?php

                        endif;

                    elseif ($type === 'images_group'):

                        if (!empty($options)):

                            ?>

                            <form class="jkd-setting jkd-setting-images-group"
                                <?php if (!empty($condition)): ?>
                                    data-condition="<?php echo esc_attr($condition); ?>"
                                <?php endif; ?>
                                  data-setting-slug="<?php echo esc_attr($slug); ?>">

                                <?php foreach ($options as $key => $option):

                                    if (!empty($option['url']) || !empty($option['svg'])):

                                        if (!empty($label)):

                                            $label = $option['label'];

                                        endif;

                                        if (!empty($option['url'])):

                                            $url = $option['url'];

                                        endif;

                                        if (!empty($option['svg'])):

                                            $svg = $option['svg'];

                                        endif;

                                        $style = '';

                                        if (!empty($sizes)):

                                            $style = 'style=min-width:'
                                                . $sizes['width']
                                                . $sizes['unit']
                                                . ';height:'
                                                . $sizes['height']
                                                . $sizes['unit'] . ';';

                                        endif;

                                        ?>

                                        <fieldset class="group-item" <?php echo esc_attr($style); ?>>

                                            <label for="<?php echo esc_attr($slug . '-' . $key) ?>"
                                                   class="item-inner">

                                                    <span class="image-wrapper <?php if (!empty($svg)):echo esc_attr('svg-wrapper');
                                                    elseif (!empty($url)):echo esc_attr('url-wrapper'); endif; ?>">

                                               <?php if (!empty($url)): ?>

                                                   <img src="<?php echo esc_url($url); ?>"
                                                        alt="<?php echo esc_attr($label); ?>">

                                               <?php endif; ?>

                                                        <?php if (!empty($svg)): ?>

                                                            <?php echo \jkdevkit\Helper::check_for_empty($svg); ?>

                                                        <?php endif; ?>

                                           </span>

                                                <span class="radio-wrapper">

                                                <input type="radio"
                                                       name="<?php echo esc_attr($slug); ?>"
                                                       class="jkd-setting-checkbox"
                                                       id="<?php echo esc_attr($slug . '-' . $key); ?>"
                                                       data-key="<?php echo esc_attr($key); ?>"
                                                       value="<?php echo esc_attr($option); ?>"
                                                       <?php if ($value === $key): ?>checked<?php endif; ?>>

                                                <span class="label">

                                                    <?php echo esc_html($label); ?>

                                                </span>

                                            </span>

                                            </label>

                                        </fieldset>

                                    <?php endif; ?>

                                <?php endforeach; ?>

                            </form>

                        <?php

                        endif;

                    elseif ($type === 'image'):

                        $image = wp_get_attachment_image_src($value, 'medium') ? wp_get_attachment_image_src($value, 'medium') : array($default);

                        ?>

                        <form class="jkd-setting jkd-setting-img-upload"
                            <?php if (!empty($condition)): ?>
                                data-condition="<?php echo esc_attr($condition); ?>"
                            <?php endif; ?>
                              data-setting-slug="<?php echo esc_attr($slug); ?>">

                            <div class="image-wrapper <?php if (empty($image)): ?>hidden<?php endif; ?>">

                                <img
                                    <?php if (!empty($image)): ?>src="<?php echo esc_url($image[0]); ?>"<?php endif; ?>
                                    alt="<?php echo esc_html__('Image Preview', 'qreatix'); ?>">

                                <span class="delete-icon">

                                    <i class="ri-close-line"></i>

                                </span>

                            </div>

                            <div class="form-side">

                                <button type="submit"
                                        class="upload-button jkd-button default-border-style size-ui animation-fill">

                                    <?php echo esc_html__('Upload Image', 'qreatix'); ?>

                                </button>

                            </div>

                        </form>

                    <?php

                    elseif ($type === 'range_slider'):

                        ?>

                        <div class="jkd-setting jkd-setting-range-slider"
                            <?php if (!empty($condition)): ?>
                                data-condition="<?php echo esc_attr($condition); ?>"
                            <?php endif; ?>
                             data-setting-slug="<?php echo esc_attr($slug); ?>">

                            <input class="range-slider-range" type="range"
                                   value="<?php echo esc_attr($value); ?>"
                                   step="<?php echo esc_attr($step); ?>"
                                   min="<?php echo esc_attr($min); ?>"
                                   max="<?php echo esc_attr($max); ?>">

                            <input class="range-slider-value"
                                   type="number"
                                   value="<?php echo esc_attr($value); ?>"
                                   step="<?php echo esc_attr($step); ?>"
                                   min="<?php echo esc_attr($min); ?>"
                                   max="<?php echo esc_attr($max); ?>">

                        </div>

                    <?php

                    elseif ($type === 'steps_slider'):

                        // TODO in progress

                        ?>

                        <div class="jkd-setting jkd-setting-steps-slider"
                            <?php if (!empty($condition)): ?>
                                data-condition="<?php echo esc_attr($condition); ?>"
                            <?php endif; ?>
                             data-setting-slug="<?php echo esc_attr($slug); ?>">

                        </div>

                    <?php

                    elseif ($type === 'number'):

                        ?>

                        <input class="jkd-setting jkd-setting-number"
                            <?php if (!empty($condition)): ?>
                                data-condition="<?php echo esc_attr($condition); ?>"
                            <?php endif; ?>
                               data-setting-slug="<?php echo esc_attr($slug); ?>"
                               type="number"
                               value="<?php echo esc_attr($value); ?>"
                               step="<?php echo esc_attr($step); ?>"
                               min="<?php echo esc_attr($min); ?>"
                               max="<?php echo esc_attr($max); ?>">

                    <?php

                    elseif ($type === 'toggle'):

                        ?>

                        <div class="jkd-setting jkd-setting-toggle <?php if ($value === 'no'): ?>disable-toggle<?php endif; ?>"
                            <?php if (!empty($to_toggle)): ?>
                                data-to-toggle="<?php echo esc_attr($to_toggle); ?>"
                            <?php endif; ?>
                            <?php if (!empty($condition)): ?>
                                data-condition="<?php echo esc_attr($condition); ?>"
                            <?php endif; ?>
                             data-setting-slug="<?php echo esc_attr($slug); ?>">

                            <input type="checkbox" <?php if ($value === 'yes'): ?>checked<?php endif; ?>>

                            <div class="knobs" data-enable-text="<?php echo esc_attr__('On', 'qreatix'); ?>">

                            <span>

                                <?php echo esc_html__('Off', 'qreatix'); ?>

                            </span>

                            </div>

                            <div class="layer">

                            </div>

                        </div>

                    <?php

                    elseif ($type === 'color_picker'):

                        ?>

                        <div class="jkd-setting jkd-setting-color-picker"
                            <?php if (!empty($color_related)): ?>
                                data-color-related="<?php echo esc_attr(json_encode($color_related)); ?>"
                            <?php endif; ?>
                            <?php if (!empty($condition)): ?>
                                data-condition="<?php echo esc_attr($condition); ?>"
                            <?php endif; ?>
                             data-setting-slug="<?php echo esc_attr($slug); ?>">

                            <input class="picker-input" type="color"
                                   value="<?php if (!empty($value)): echo esc_attr($value); endif; ?>">

                            <input class="color-text-input" type="text" autocomplete="off" spellcheck="false"
                                   value="<?php if (!empty($value)): echo esc_attr($value); endif; ?>">

                        </div>

                    <?php

                    elseif ($type === 'color_scheme'):

                        if (!empty($options)):

                            ?>

                            <div class="jkd-setting jkd-setting-color-scheme"
                                <?php if (!empty($condition)): ?>
                                    data-condition="<?php echo esc_attr($condition); ?>"
                                <?php endif; ?>
                                 data-setting-slug="<?php echo esc_attr($slug); ?>">

                                <?php foreach ($options as $key => $scheme):

                                    $scheme_data = array('key' => $key, 'data' => $scheme);

                                    if (!empty($scheme_data)):

                                        ?>

                                        <label class="scheme-wrapper"
                                               for="<?php echo esc_attr($slug . '-' . $key); ?>">

                                            <input type="radio"
                                                   class="jkd-setting-checkbox"
                                                   name="<?php echo esc_attr($slug); ?>"
                                                   id="<?php echo esc_attr($slug . '-' . $key); ?>"
                                                   data-key="<?php echo esc_attr($key); ?>"
                                                   data-scheme="<?php echo esc_attr(json_encode($scheme_data, JSON_FORCE_OBJECT)); ?>"
                                                   value="<?php echo esc_attr($key); ?>"
                                                   <?php if (!empty($value['key']) && $value['key'] === $key): ?>checked<?php endif; ?>>

                                            <span class="scheme-side">

                                            <?php foreach ($scheme as $inner_color): ?>

                                                <?php if (!empty($inner_color)): ?>

                                                    <span class="color-wrapper">

                                                    <span class="color"
                                                          style="background-color: <?php echo esc_attr($inner_color); ?>;">

                                                    </span>

                                                        <span class="color-hex">

                                                        <?php echo esc_html($inner_color); ?>

                                                    </span>

                                                </span>

                                                <?php endif; ?>

                                            <?php endforeach; ?>

                                        </span>

                                        </label>

                                    <?php endif; ?>

                                <?php endforeach; ?>

                            </div>

                        <?php

                        endif;

                    elseif ($type === 'tags_group'):

                        ?>

                        <div class="jkd-setting jkd-settings-tags-group <?php if (!empty($ui)): echo esc_attr('ui-' . $ui); endif; ?>" <?php if (!empty($condition)): ?>
                            data-condition="<?php echo esc_attr($condition); ?>"
                        <?php endif; ?>
                             data-setting-slug="<?php echo esc_attr($slug); ?>">

                            <div class="tags-wrapper">

                                <?php foreach ($value as $tag): ?>

                                    <button class="jkd-button tag default-tag size-ui <?php if ($tag['slug'] === 'uncategorized'): ?> uncategorized <?php endif; ?>"
                                            style="color: <?php echo esc_attr($tag['color']); ?>;border-color: <?php echo esc_attr($tag['color']); ?>"
                                            data-tag-color="<?php echo esc_attr($tag['color']); ?>"
                                            data-tag-name="<?php echo esc_attr($tag['name']); ?>"
                                            data-tag-slug="<?php echo esc_attr($tag['slug']); ?>">

                                        <?php echo esc_html($tag['name']); ?>

                                        <?php if ($tag['slug'] !== 'uncategorized'): ?>

                                            <i class="ri-close-line tag-remove"></i>

                                        <?php endif; ?>

                                    </button>

                                <?php endforeach; ?>

                                <div class="add-new-tag-wrapper">

                                    <button class="jkd-button add-new-tag size-ui">

                                        <span class="plus-icon">

                                            <?php echo esc_html('+'); ?>

                                        </span>

                                        <i class="ri-close-line close-icon"></i>

                                    </button>

                                    <div class="new-tag-form">

                                        <h6 class="tag-form-title">

                                            <?php echo esc_html('Add new:'); ?>

                                        </h6>

                                        <div class="input-row">

                                            <div class="input-item">

                                                <input type="text" class="jkd-setting-text tag-slug-input"
                                                       name="tag-slug"
                                                       placeholder="<?php echo esc_attr__('Slug', 'qreatix'); ?>">

                                                <p class="jkd-notice hidden danger small tag-slug-notice">

                                                    <span class="notice-text"></span>

                                                </p>

                                            </div>

                                            <div class="input-item">

                                                <input type="text" class="jkd-setting-text tag-name-input"
                                                       name="tag-name"
                                                       placeholder="<?php echo esc_attr__('Name', 'qreatix'); ?>">

                                                <p class="jkd-notice hidden danger small tag-name-notice">

                                                    <span class="notice-text"></span>

                                                </p>

                                            </div>

                                            <div class="input-item">

                                                <div class="jkd-setting-color-picker">

                                                    <input class="picker-input" type="color"
                                                           value="<?php echo esc_attr('#1f6ba0'); ?>">

                                                    <input class="color-text-input" type="text"
                                                           autocomplete="off"
                                                           spellcheck="false"
                                                           value="<?php echo esc_attr('#1f6ba0'); ?>">

                                                </div>

                                                <p class="jkd-notice hidden danger small tag-color-notice">

                                                    <span class="notice-text"></span>

                                                </p>

                                            </div>

                                            <div class="input-item">

                                                <button class="jkd-button size-ui add-new-button wp-style animation-fade">

                                                    <span class="static-text">

                                                        <?php echo esc_html__('Add +', 'qreatix'); ?>

                                                    </span>

                                                    <span class="loading-text">

                                                        <?php echo esc_html__('Loading', 'qreatix'); ?>

                                                    </span>

                                                    <?php \jkdevkit\Helper::loader_render(); ?>

                                                </button>

                                                <p class="jkd-notice hidden danger small tag-submit-notice">

                                                    <span class="notice-text"></span>

                                                </p>

                                            </div>

                                        </div>

                                    </div>

                                </div>

                            </div>

                        </div>

                    <?php

                    endif;

                    if (!empty($notice) && !empty($notice['text'])):

                        ?>

                        <div class="jkd-notice margin-top <?php if (!empty($notice['type'])):
                            echo esc_attr($notice['type']); endif; ?>">

                            <i class="ri-close-line close-notice"></i>

                            <?php if (!empty($notice['icon'])): ?>

                                <i class="notice-icon <?php echo esc_attr($notice['icon']); ?>"></i>

                            <?php endif; ?>

                            <p class="notice-text">

                                <?php echo esc_html($notice['text']); ?>

                            </p>

                        </div>

                    <?php

                    endif;

                    ?>

                </div>

            <?php

            endif;

        endif;

    }

}

Controls_Manager::instance();
