<?php

namespace jkdevkit;

defined('ABSPATH') || exit;

class Fonts_Manager extends \jkdevkit
{

    /**
     * @var null
     */
    private static $_instance = null;

    /**
     * @return \jkdevkit\Fonts_Manager
     */
    public static function instance()
    {

        if (is_null(self::$_instance)) :

            self::$_instance = new self();

        endif;

        return self::$_instance;

    }

    /**
     *
     */
    public function __construct()
    {

        /* font filetype correction */
        add_filter('wp_check_filetype_and_ext', [$this, 'font_correct_filetypes'], 10, 5);

        $this->init_ajax();

    }

    /**
     * @return void
     */
    public function init_ajax()
    {

        /* ajax upload font handler */
        add_action('wp_ajax_nopriv_jkd_upload_font_handler', [$this, 'font_upload_handler']);
        add_action('wp_ajax_jkd_upload_font_handler', [$this, 'font_upload_handler']);

        /* ajax render font adding form handler */
        add_action('wp_ajax_nopriv_jkd_font_adding_form_handler', [$this, 'font_adding_form_render']);
        add_action('wp_ajax_jkd_font_adding_form_handler', [$this, 'font_adding_form_render']);

        /* ajax render font adding form handler */
        add_action('wp_ajax_nopriv_jkd_custom_font_add_row_handler', [$this, 'add_custom_font_row']);
        add_action('wp_ajax_jkd_custom_font_add_row_handler', [$this, 'add_custom_font_row']);

        /* ajax remove font handler */
        add_action('wp_ajax_nopriv_jkd_remove_font_handler', [$this, 'remove_font_handler']);
        add_action('wp_ajax_jkd_remove_font_handler', [$this, 'remove_font_handler']);

        /* ajax edit font handler */
        add_action('wp_ajax_nopriv_jkd_edit_font_handler', [$this, 'edit_font_handler']);
        add_action('wp_ajax_jkd_edit_font_handler', [$this, 'edit_font_handler']);

    }

    /**
     * @return void
     */
    public function add_custom_font_row()
    {

        $this->custom_font_row(true);

        /* exit */
        die();

    }

    /**
     * @return void
     */
    public function remove_font_handler()
    {

        $slug = $_POST['slug'];

        $fonts_library = $this->get_fonts_library();

        unset($fonts_library[$slug]);

        update_option('jkd_fonts_library', $fonts_library, false);

        /* exit */
        die();

    }

    /**
     * @return void
     */
    public function edit_font_handler()
    {

        $fonts_library = $this->get_fonts_library();

        $slug = $_POST['slug'];

        $font = $fonts_library[$slug];

        $this->edit_font_popup($font);

        /* exit */
        die();

    }

    /**
     * @param $font
     *
     * @return void
     */
    public function edit_font_popup($font)
    {

        $name = $font['name'];

        $type = $font['type'];

        ?>

        <div class="edit-popup">

            <i class="ri-close-line close-button"></i>

            <div class="popup-header">

                <?php echo esc_html__('Edit', 'qreatix'); ?>

                <span class="font-name">

                        <?php echo esc_html('"' . $name . '"'); ?>

                    </span>

            </div>

            <div class="popup-body">

                <?php if ($type === 'custom'): ?>


                <?php elseif ($type === 'google'): ?>
                <?php elseif ($type === 'typekit'): ?>

                <?php endif; ?>

            </div>

        </div>

        <?php

    }

    /**
     * @param $actions
     *
     * @return void
     */
    public function custom_font_row($actions = false)
    {

        ?>

        <div class="font-row">

            <div class="input-wrapper">

                <h6 class="setting-title">

                    <?php echo esc_html__('Font Weight', 'qreatix'); ?>

                </h6>

                <p class="setting-description">

                    <?php echo esc_html__('Select the font weight.', 'qreatix'); ?>

                </p>

                <select class="jkd-setting jkd-setting-select">

                    <option value="100" selected>

                        <?php echo esc_html('Thin (100)'); ?>

                    </option>

                    <option value="200">

                        <?php echo esc_html('Extra-Light (200)'); ?>

                    </option>

                    <option value="300">

                        <?php echo esc_html('Light (300)'); ?>

                    </option>

                    <option value="400">

                        <?php echo esc_html('Normal (400)'); ?>

                    </option>

                    <option value="500">

                        <?php echo esc_html('Medium (500)'); ?>

                    </option>

                    <option value="600">

                        <?php echo esc_html('Semi-Bold (600)'); ?>

                    </option>

                    <option value="700">

                        <?php echo esc_html('Bold (700)'); ?>

                    </option>

                    <option value="800">

                        <?php echo esc_html('Extra-Bold (800)'); ?>

                    </option>

                    <option value="900">

                        <?php echo esc_html('Ultra-Bold (900)'); ?>

                    </option>

                </select>

            </div>

            <div class="input-wrapper">

                <h6 class="setting-title">

                    <?php echo esc_html__('Font File', 'qreatix'); ?>

                </h6>

                <p class="setting-description">

                    <?php echo esc_html__('Upload the font file.', 'qreatix'); ?>

                </p>

                <div class="upload-file-wrapper">

                    <!-- upload file button -->
                    <button class="action-button upload-font-button jkd-button wp-border-style size-ui animation-fill">

                        <?php echo esc_html__('Upload Font', 'qreatix'); ?>

                    </button>

                    <input type="file" name="file" class="file-input hidden-input"
                           id="file"/>

                    <div class="upload-file-status">

                    </div>

                </div>

            </div>

            <?php if ($actions): ?>

                <i class="ri-close-line font-var-remove"></i>

            <?php endif; ?>

        </div>

        <?php

    }

    /**
     * @param $font
     *
     * @return void
     */
    public static function font_item_render($font)
    {

        $name = $font['name'];

        $type = $font['type'];

        ?>

        <li class="font-item <?php echo esc_attr($type . '-font'); ?>"
            data-slug="<?php echo esc_attr(str_replace('/\s+/', '-', trim($name))); ?>">

            <div class="left-side">

                <div class="type-icon">

                    <?php if ($type === 'custom'): ?>

                        <i class="ri-heading"></i>

                    <?php elseif ($type === 'google'): ?>

                        <i class="ri-google-line"></i>

                    <?php elseif ($type === 'typekit'): ?>

                        <i class="ri-font-size-2"></i>

                    <?php endif; ?>

                </div>

                <h6 class="font-name">

                    <?php echo esc_html($name); ?>

                </h6>

                <div class="action-buttons">

                    <button class="action-button edit-button">

                        <?php echo esc_html__('Edit', 'qreatix'); ?>

                    </button>

                    <button class="action-button remove-button">

                        <?php echo esc_html__('Remove', 'qreatix'); ?>

                    </button>

                </div>

            </div>

            <div class="right-side">

            </div>

        </li>

        <?php

    }

    /**
     * @return void
     */
    public function font_upload_handler()
    {

        $fonts_library = $this->get_fonts_library();

        $name = $_POST['name'];

        if (!empty($name)):

            $fallback = $_POST['fallback'];

            if (!empty($fallback)):

                $display = $_POST['display'];

                if (!empty($display)):

                    $fws = explode(',', $_POST['fws']);

                    if (!empty($fws)):

                        $files = $_FILES['file'];

                        if (!empty($files)):

                            $font = array(
                                'type' => 'custom',
                                'name' => $name,
                                'fallback' => $fallback,
                                'display' => $display,
                                'fws' => $fws,
                                'files' => array()
                            );

                            foreach ($files['name'] as $key => $value) :

                                if ($files['name'][$key]) :

                                    $file = array(
                                        'name' => $files['name'][$key],
                                        'type' => $files['type'][$key],
                                        'tmp_name' => $files['tmp_name'][$key],
                                        'error' => $files['error'][$key],
                                        'size' => $files['size'][$key]
                                    );

                                    $response = wp_handle_upload($file, array('test_form' => false));

                                    $font['files'][] = $response;

                                endif;

                            endforeach;

                            $fonts_library[str_replace('/\s+/', '-', trim($name))] = $font;

                            update_option('jkd_fonts_library', $fonts_library, false);

                            ob_start();

                            ?>

                            <div class="success-wrapper">

                                <i class="ri-check-line success-icon"></i>

                                <h5 class="success-title">

                                    <strong>

                                        <?php echo esc_html($name); ?>

                                    </strong>

                                    <?php echo esc_html__(' was successfully added to the fonts library', 'qreatix'); ?>

                                </h5>

                                <button class="jkd-button add-another-button wp-style size-ui animation-fade">

                                    <?php echo esc_html__('Add Another +', 'qreatix'); ?>

                                </button>

                            </div>

                            <?php

                            $success = ob_get_clean();

                            ob_start();

                            $this->font_item_render($font);

                            $item = ob_get_clean();

                            print_r(json_encode(array(
                                'success' => $success,
                                'item' => $item
                            )));

                        endif;

                    endif;

                endif;

            endif;

        endif;

        /* exit */
        die();

    }

    /**
     * @return void
     */
    public function font_adding_form_render()
    {

        /* type var */
        $type = $_POST['type'];

        /* if type var === custom */
        if ($type === 'custom'):

            ?>

            <div class="custom-font-form">

                <div class="font-main-values">

                    <div class="input-wrapper">

                        <h6 class="setting-title">

                            <?php echo esc_html__('Font Name', 'qreatix'); ?>

                        </h6>

                        <p class="setting-description">

                            <?php echo esc_html__('Enter the font name.', 'qreatix'); ?>

                        </p>

                        <input type="text"
                               class="jkd-setting jkd-setting-text jkd-font-name"
                               placeholder="<?php echo esc_attr__('Name', 'qreatix'); ?>" required>

                        <p class="jkd-notice hidden danger small font-name-notice">

                            <span class="notice-text"></span>

                        </p>

                    </div>

                    <div class="input-wrapper">

                        <h6 class="setting-title">

                            <?php echo esc_html__('Font Fallback', 'qreatix'); ?>

                        </h6>

                        <p class="setting-description">

                            <?php echo esc_html__('Add the font\'s fallback names', 'qreatix'); ?>

                        </p>

                        <input type="text"
                               class="jkd-setting jkd-setting-text jkd-font-fallback"
                               value="<?php echo esc_attr('Arial, sans-serif'); ?>"
                               placeholder="<?php echo esc_attr('Arial, sans-serif'); ?>">

                        <p class="jkd-notice hidden danger small font-fallback-notice">

                            <span class="notice-text"></span>

                        </p>

                    </div>

                    <div class="input-wrapper">

                        <h6 class="setting-title">

                            <?php echo esc_html__('Font Display', 'qreatix'); ?>

                        </h6>

                        <p class="setting-description">

                            <?php echo esc_html__('Enter the font name.', 'qreatix'); ?>

                        </p>

                        <select class="jkd-setting jkd-setting-select jkd-font-display">

                            <option value="auto" selected>

                                <?php echo esc_html('auto'); ?>

                            </option>

                            <option value="block">

                                <?php echo esc_html('block'); ?>

                            </option>

                            <option value="swap">

                                <?php echo esc_html('swap'); ?>

                            </option>

                            <option value="fallback">

                                <?php echo esc_html('fallback'); ?>

                            </option>

                            <option value="optional">

                                <?php echo esc_html('optional'); ?>

                            </option>

                        </select>

                        <p class="jkd-notice hidden danger small font-display-notice">

                            <span class="notice-text"></span>

                        </p>

                    </div>

                </div>

                <div class="font-variations-repeater">

                    <?php $this->custom_font_row(); ?>

                    <div class="add-new-button-wrapper">

                        <!-- add new font row button -->
                        <button class="action-button add-new-font-row jkd-button wp-style size-ui animation-fade">

                                <span class="static-text">

                                       <?php echo esc_html__('Add New Variation', 'qreatix'); ?>

                                </span>

                            <span class="loading-text">

                                    <?php echo esc_html__('Loading', 'qreatix'); ?>

                                    <?php Helper::loader_render(); ?>

                                </span>

                        </button>

                        <!-- add to library -->
                        <button class="action-button add-to-library jkd-button wp-style size-ui animation-fade">

                                <span class="static-text">

                                       <?php echo esc_html__('Add To Library +', 'qreatix'); ?>

                                </span>

                            <span class="loading-text">

                                    <?php echo esc_html__('Loading', 'qreatix'); ?>

                                    <?php Helper::loader_render(); ?>

                                </span>

                        </button>

                    </div>

                </div>

            </div>

        <?php

        elseif ($type === 'google'):

        elseif ($type === 'typekit'):

        endif;

        /* exit */
        die();

    }

    /**
     * @return false|mixed|void
     */
    public static function get_fonts_library()
    {

        return get_option('jkd_fonts_library', array());

    }

    /**
     * @param $data
     * @param $file
     * @param $filename
     * @param $mimes
     * @param $real_mime
     *
     * @return mixed
     */
    public function font_correct_filetypes($data, $file, $filename, $mimes, $real_mime)
    {

        /* check if ext and type is not empty */
        if (!empty($data['ext']) && !empty($data['type'])) :

            /* return data */
            return $data;

        endif;

        /* get uploaded filetype */
        $wp_file_type = wp_check_filetype($filename, $mimes);

        /* if filetype is 'ttf' */
        if ('ttf' === $wp_file_type['ext']) :

            $data['ext'] = 'ttf';

            $data['type'] = 'font/ttf';

        endif;

        /* if filetype is 'otf' */
        if ('otf' === $wp_file_type['ext']):

            $data['ext'] = 'otf';

            $data['type'] = 'font/otf';

        endif;

        /* return data */
        return $data;

    }

}

Fonts_Manager::instance();
