<?php

namespace jkdevkit;

defined('ABSPATH') || exit;

class Helper extends \jkdevkit
{

    /**
     * @return void
     */
    public static function loader_render()
    {

        ?>

        <!-- default shell loader -->
        <svg viewBox="0 0 58 58" xmlns="http://www.w3.org/2000/svg" class="loader">

            <g fill="none" fill-rule="evenodd">

                <g transform="translate(2 1)" stroke-width="1.5" class="loader-stroke-color">

                    <circle cx="42.601" cy="11.462" r="5" fill-opacity="1" class="loader-color">

                        <animate attributeName="fill-opacity"
                                 begin="0s" dur="1.3s"
                                 values="1;0;0;0;0;0;0;0" calcMode="linear"
                                 repeatCount="indefinite"/>

                    </circle>

                    <circle cx="49.063" cy="27.063" r="5" fill-opacity="0" class="loader-color">

                        <animate attributeName="fill-opacity"
                                 begin="0s" dur="1.3s"
                                 values="0;1;0;0;0;0;0;0" calcMode="linear"
                                 repeatCount="indefinite"/>

                    </circle>

                    <circle cx="42.601" cy="42.663" r="5" fill-opacity="0" class="loader-color">

                        <animate attributeName="fill-opacity"
                                 begin="0s" dur="1.3s"
                                 values="0;0;1;0;0;0;0;0" calcMode="linear"
                                 repeatCount="indefinite"/>
                    </circle>

                    <circle cx="27" cy="49.125" r="5" fill-opacity="0" class="loader-color">

                        <animate attributeName="fill-opacity"
                                 begin="0s" dur="1.3s"
                                 values="0;0;0;1;0;0;0;0" calcMode="linear"
                                 repeatCount="indefinite"/>

                    </circle>

                    <circle cx="11.399" cy="42.663" r="5" fill-opacity="0" class="loader-color">

                        <animate attributeName="fill-opacity"
                                 begin="0s" dur="1.3s"
                                 values="0;0;0;0;1;0;0;0" calcMode="linear"
                                 repeatCount="indefinite"/>

                    </circle>

                    <circle cx="4.938" cy="27.063" r="5" fill-opacity="0" class="loader-color">

                        <animate attributeName="fill-opacity"
                                 begin="0s" dur="1.3s"
                                 values="0;0;0;0;0;1;0;0" calcMode="linear"
                                 repeatCount="indefinite"/>

                    </circle>

                    <circle cx="11.399" cy="11.462" r="5" fill-opacity="0" class="loader-color">

                        <animate attributeName="fill-opacity"
                                 begin="0s" dur="1.3s"
                                 values="0;0;0;0;0;0;1;0" calcMode="linear"
                                 repeatCount="indefinite"/>

                    </circle>

                    <circle cx="27" cy="5" r="5" fill-opacity="0" class="loader-color">

                        <animate attributeName="fill-opacity"
                                 begin="0s" dur="1.3s"
                                 values="0;0;0;0;0;0;0;1" calcMode="linear"
                                 repeatCount="indefinite"/>

                    </circle>

                </g>

            </g>

        </svg>

        <?php

    }

    /**
     * @param array $args
     *
     * @return void
     */
    public static function add_alert(array $args = array())
    {

        if (!empty($args)):

            $classes = array();

            if (!empty($args['slug'])):

                $classes[] = $args['slug'];

            endif;

            if (!empty($args['type'])):

                $classes[] = $args['type'];

            endif;

            if (!empty($args['border'])):

                $classes[] = $args['border'] . '-border';

            endif;

            $classes = implode(' ', $classes);

            ?>

            <!-- alert message -->
            <div class="alert-message <?php echo esc_attr($classes); ?>">

                <!-- alert icon -->
                <i class="<?php echo esc_attr($args['icon']); ?> alert-icon"></i>

                <!-- right side -->
                <div class="right-side">

                    <!-- title wrapper -->
                    <div class="title-wrapper">

                        <!-- alert title -->
                        <h6 class="alert-title">

                            <?php echo esc_attr($args['title']); ?>

                        </h6>

                        <!-- alert subtitle -->
                        <p class="alert-subtitle">

                            <?php echo esc_attr($args['description']); ?>

                        </p>

                    </div>

                </div>

                <?php if ($args['slug'] === 'support-expired'): ?>

                    <!-- buttons wrapper -->
                    <div class="buttons-wrapper">

                        <!-- link -->
                        <a href="<?php echo esc_url($args['renew_guide']); ?>" target="_blank"
                           class="jkd-link">

                            <?php echo esc_html($args['renew_guide_title']); ?>

                        </a>

                        <!-- button -->
                        <a class="jkd-button envato-style animation-fill size-ui" target="_blank"
                           href="<?php echo esc_url($args['renew_link']); ?>">

                            <?php echo esc_html($args['renew_link_title']); ?>

                            <i class="ri-arrow-right-line right-icon"></i>

                        </a>

                    </div>

                <?php

                endif;

                ?>

            </div>

        <?php

        endif;

    }

    /**
     * @param $value
     *
     * @return void
     */
    public static function debug($value)
    {

        /* DEBUG MESSAGE START */
        print_r('<!-- DEBUG MESSAGE START -->');

        print_r('<pre>');

        print_r($value);

        print_r('</pre>');

        print_r('<!-- DEBUG MESSAGE END -->');
        /* DEBUG MESSAGE END */

    }

    /**
     * @param $path
     * @param array $atts
     *
     * @return void
     */
    public static function template($path, array $atts = array())
    {

        /* NOTE! $atts is not unused, it uses in included templates */

        $override_path = get_template_directory() . '/jkd-templates/' . $path . '.php';

        $real_path = dirname(__FILE__, 2) . '/templates/' . $path . '.php';

        if (is_file($override_path)):

            include($override_path);

        elseif (is_file($real_path)):

            include($real_path);

        else:

            echo esc_html__('No such template in ', 'qreatix') . esc_url($real_path);

        endif;

    }

    /**
     * @param $time1
     * @param $time2
     *
     * @return false|int
     */
    public static function compare_by_time_stamp($time1, $time2)
    {

        /* first date */
        $datetime1 = strtotime($time1['date']);

        /* second date */
        $datetime2 = strtotime($time2['date']);

        /* comparation */
        return $datetime1 - $datetime2;

    }

    /**
     * @return array
     */
    public static function phpinfo_array(): array
    {

        ob_start();

        phpinfo();

        $s = ob_get_contents();

        ob_end_clean();

        $s = strip_tags($s, '<h2><th><td>');

        $s = preg_replace('/<th[^>]*>([^<]+)<\/th>/', '<info>\1</info>', $s);

        $s = preg_replace('/<td[^>]*>([^<]+)<\/td>/', '<info>\1</info>', $s);

        $t = preg_split('/(<h2[^>]*>[^<]+<\/h2>)/', $s, -1, PREG_SPLIT_DELIM_CAPTURE);

        $r = array();

        $count = count($t);

        $p1 = '<info>([^<]+)<\/info>';

        $p2 = '/' . $p1 . '\s*' . $p1 . '\s*' . $p1 . '/';

        $p3 = '/' . $p1 . '\s*' . $p1 . '/';

        for ($i = 1; $i < $count; $i++) :

            if (preg_match('/<h2[^>]*>([^<]+)<\/h2>/', $t[$i], $matches)) :

                $name = trim($matches[1]);

                $values = explode("\n", $t[$i + 1]);

                foreach ($values as $val) :

                    if (preg_match($p2, $val, $matches)) :

                        $r[$name][trim($matches[1])] = array(trim($matches[2]), trim($matches[3]));

                    elseif (preg_match($p3, $val, $matches)) :

                        $r[$name][trim($matches[1])] = trim($matches[2]);

                    endif;

                endforeach;

            endif;

        endfor;

        return $r;

    }

    /**
     * @param $dir
     * @param array $results
     *
     * @return array
     */
    public static function get_dir_contents($dir, array &$results = array()): array
    {

        /* get directory files */
        $files = scandir($dir);

        /* files loop */
        foreach ($files as $key => $value) :

            /* current file path */
            $path = realpath($dir . DIRECTORY_SEPARATOR . $value);

            /* check if path is dir */
            if (!is_dir($path)) :

                /* add path to results */
                $results[] = $path;

            elseif ($value != "." && $value != "..") :

                /* recurse path parse */
                self::get_dir_contents($path, $results);

                /* add path to results */
                $results[] = $path;

            endif;

        endforeach;

        /* return results */
        return $results;

    }

    /**
     * @param $str
     *
     * @return string
     */
    public function check_for_empty($str): string
    {

        if (!empty($str)):

            return $str;

        else:

            return '';

        endif;

    }

}
