<?php

namespace jkdevkit;

use \DateTime;

defined('ABSPATH') || exit;

class License_Manager extends \jkdevkit
{

    /**
     * @var
     */
    public $instance;

    /**
     * @return mixed
     */
    public function getInstance()
    {
        return $this->instance;
    }

    /**
     * @param mixed $instance
     */
    public function setInstance($instance): void
    {
        $this->instance = $instance;
    }

    /**
     * @param $instance
     *
     * @throws \Exception
     */
    public function __construct($instance)
    {

        $this->setInstance($instance);

        $this->setActivation(get_option($this->getInstance()->slug . '_jkd_activation', false));

        $this->setActivationData(get_option($this->getInstance()->slug . '_jkd_activation_data', array()));

        /* get activation check */
        $activation = $this->getInstance()->isActivation();

        /* remote meta data checker */
        $this->update_meta_data();

        /* remote domain checker */
        $this->domain_verification();

        /* init ajax */
        $this->init_ajax();

        /* if no activation there */
        if (!$activation
            && !empty($_GET['page'])
            && $_GET['page'] !== $this->getInstance()->slug
            || !$activation
            && empty($_GET['page'])):

            /* admin_notices action */
            add_action('admin_notices', [$this, 'item_not_activated_notice']);

        endif;

    }

    /**
     * @return void
     */
    public function init_ajax()
    {

        /* ajax activation handler */
        add_action('wp_ajax_nopriv_jkd_activation_handler', [$this, 'activation_handler']);
        add_action('wp_ajax_jkd_activation_handler', [$this, 'activation_handler']);

        /* ajax deactivation handler */
        add_action('wp_ajax_nopriv_jkd_deactivation_handler', [$this, 'deactivation_handler']);
        add_action('wp_ajax_jkd_deactivation_handler', [$this, 'deactivation_handler']);

        /* ajax update license handler */
        add_action('wp_ajax_nopriv_jkd_update_license_handler', [$this, 'force_update_license_info']);
        add_action('wp_ajax_jkd_update_license_handler', [$this, 'force_update_license_info']);

        /* ajax update metadata handler */
        add_action('wp_ajax_nopriv_jkd_update_metadata_handler', [$this, 'force_update_metadata']);
        add_action('wp_ajax_jkd_update_metadata_handler', [$this, 'force_update_metadata']);

    }

    /**
     * @return void
     * @throws \Exception
     */
    public function force_update_license_info()
    {

        /* force domain verification */
        $this->domain_verification(true);

        /* exit */
        die();

    }

    /**
     * @return void
     * @throws \Exception
     */
    public function force_update_metadata()
    {

        /* force metadata update */
        $this->update_meta_data(true);

        /* exit */
        die();

    }

    /**
     * @param bool $force
     *
     * @return void
     * @throws \Exception
     */
    public function update_meta_data(bool $force = false)
    {

        /* current date */
        $current_date = new DateTime(date('Y-m-d-G'));

        /* expire date */
        $expire_date = get_option($this->getInstance()->slug . '_meta_expire');

        /* check options status || comparing */
        if ($current_date >= $expire_date
            || empty($expire_date)
            || $force):

            /* remote url */
            $url = "https://jk-studio-dev.com/wp-content/themes/jk-studio-dev/json/" . $this->getInstance()->slug . ".json";

            /* get data from remote url */
            $resp = wp_remote_post($url, array(
                'method' => 'POST',
                'timeout' => 45,
                'redirection' => 5,
                'httpversion' => '1.0',
                'blocking' => true,
                'headers' => array(
                    "Content-Type: application/json",
                    "Content-Length: 0",
                ),
            ));

            /* response body */
            $resp = wp_remote_retrieve_body($resp);

            /* check if response is not empty */
            if (!empty($resp)):

                /* decode json data to php associative array */
                $json_data = json_decode($resp, true);

                /* check if json data is not empty */
                if (!empty($json_data)):

                    /* expire date */
                    $expire_date = new DateTime(date('Y-m-d-G'));

                    /* update meta data */
                    update_option($this->getInstance()->slug . '_meta', $json_data, false);

                    update_option($this->getInstance()->slug . '_meta_update', $expire_date, false);

                    /* check if metadata is not empty */
                    if (!empty($expire_date)):

                        /* add +6 hours to expire date */
                        $expire_date->modify('+6 hours');

                        /* update meta expire date */
                        update_option($this->getInstance()->slug . '_meta_expire', $expire_date, false);

                    endif;

                endif;

            endif;

        endif;

    }

    /**
     * @return void
     * @throws \Exception
     */
    public function activation_handler()
    {

        /* get activation data from jk-studio API */
        $data = $_POST['data'];

        /* activate if data exists */
        if (!empty($data)):

            /* remove extra slashes */
            $data = str_replace('\\', '', $data);

            /* decode json data */
            $data = json_decode($data);

            /* set trigger of activation theme */
            if ($data->status !== 'not-activated'):

                /* next verification check */
                $next_check = new DateTime(date('F j, Y, g:i a'));

                /* add 24+ hours to next verification check */
                $next_check->modify('+24 hours');

                /* update activation data */
                update_option($this->getInstance()->slug . '_jkd_activation_data', $data, false);

                /* update activation option */
                update_option($this->getInstance()->slug . '_jkd_activation', true, false);

                /* update verification check */
                update_option($this->getInstance()->slug . '_jkd_domain_verification_check', new DateTime(date('F j, Y, g:i a')), false);

                /* update next verification check */
                update_option($this->getInstance()->slug . '_jkd_domain_verification_next', $next_check, false);

            endif;

        endif;

        /* exit */
        die();

    }

    /**
     * @return void
     */
    public function deactivation_handler()
    {

        /* reset activation options */
        update_option($this->getInstance()->slug . '_jkd_activation', false);

        /* reset activation options */
        update_option($this->getInstance()->slug . '_jkd_activation_data', false);

        /* reset activation options */
        update_option($this->getInstance()->slug . '_jkd_domain_verification_check', false);

        /* reset activation options */
        update_option($this->getInstance()->slug . '_jkd_domain_verification_next', false);

        /* exit */
        die();

    }

    /**
     * @param bool $force
     *
     * @return void
     * @throws \Exception
     */
    public function domain_verification(bool $force = false)
    {

        /* current date */
        $current_date = new DateTime(date('F j, Y, g:i a'));

        /* next domain verification check */
        $next_check = get_option($this->getInstance()->slug . '_jkd_domain_verification_next');

        /* get activation check */
        $activation = $this->getInstance()->isActivation();

        /* activation data */
        $data = $this->getInstance()->getActivationData();

        /* check dates and activation */
        if (!$activation
            || $current_date >= $next_check
            || empty($next_check)
            || $force):

            /* empty key array */
            $key = '';

            if (!empty($data)
                && !empty($data->code)):

                $key = $data->code;

            endif;

            if (!empty($this->getInstance()->version)):

                $version = $this->getInstance()->version;

            endif;

            if (!empty($this->getInstance()->id)):

                $id = $this->getInstance()->id;

            endif;

            /* next verification date */
            $next_check = new DateTime(date('F j, Y, g:i a'));

            /* add 24 hours to next check */
            $next_check->modify('+24 hours');

            /* update next verification option */
            update_option($this->getInstance()->slug . '_jkd_domain_verification_next', $next_check, false);

            /* remote url */
            $url = 'https://jk-studio-dev.com/api/check/domain_for_activation/?';

            $query = http_build_query(array(
                'domain' => esc_url(home_url()),
                'id' => esc_attr($id),
                'version' => esc_attr($version),
                'key' => esc_attr($key),
            ));

            $url = $url . $query;

            /* get data from remote url */
            $resp = wp_remote_post($url, array(
                'method' => 'POST',
                'timeout' => 45,
                'redirection' => 5,
                'httpversion' => '1.0',
                'blocking' => true,
                'headers' => array(
                    "Content - Type: application / json",
                    "Content - Length: 0",
                ),
            ));

            /* get body */
            $resp = wp_remote_retrieve_body($resp);

            /* decode json */
            $resp = json_decode($resp);

            /* check if not empty */
            if (!empty($resp)
                && !empty($resp->data)
                && !empty($resp->status)
                && $resp->status === 200):

                /* update verification check option */
                update_option($this->getInstance()->slug . '_jkd_domain_verification_check', new DateTime(date('F j, Y, g:i a')), false);

                $this->setActivation($resp->activation);

                /* update activation data */
                $this->setActivationData($resp->data);

                update_option($this->getInstance()->slug . '_jkd_activation', $resp->activation);

                update_option($this->getInstance()->slug . '_jkd_activation_data', $resp->data);

            endif;

        endif;

    }

    /**
     * @return void
     */
    public function item_not_activated_notice()
    {

        /* class */
        $class = 'notice notice-warning';

        /* message */
        $message = __('Warning! ', 'qreatix') . $this->getInstance()->name . __(' is not activated! To activate, go to:', 'qreatix');

        /* alert */
        printf('<div class="%1$s"><p>%2$s <a href="' . esc_url(admin_url() . 'admin.php?page=' . $this->getInstance()->slug) . '">' . esc_html__('License', 'qreatix') . '</a></p></div>', esc_attr($class), esc_html($message));

    }

}
