<?php

namespace jkdevkit;

use \DateTime;

defined('ABSPATH') || exit;

class Shell extends \jkdevkit
{

    /**
     * @var
     */
    public $instance;

    /**
     * @return mixed
     */
    public function getInstance()
    {
        return $this->instance;
    }

    /**
     * @param mixed $instance
     */
    public function setInstance($instance): void
    {
        $this->instance = $instance;
    }

    /**
     * @param $args
     * @param $instance
     *
     * @throws \Exception
     */
    public function __construct($args, $instance)
    {

        $this->setInstance($instance);

        $this->render($args);

    }

    /**
     * @param array $args
     *
     * @return false|void
     * @throws \Exception
     */
    public function render(array $args = array())
    {

        /* check if args is not empty */
        if (empty($args)):

            /* if empty = exit */
            return false;

        endif;

        /* enqueue media scripts/styles for media uploaders */
        wp_enqueue_media();

        /* current tab */
        $current_tab = $args['default_tab'];

        if (!empty($_GET['current_tab'])):

            /* current tab get-query value */
            $current_tab = $_GET['current_tab'];

        endif;

        /* get current activation */
        $activation = get_option($args['slug'] . '_jkd_activation');

        /* get current activation data */
        $activation_data = get_option($args['slug'] . '_jkd_activation_data');

        /* empty classes array */
        $classes = array();

        /* shell view default value */
        $shell_view = 'minimal';

        /* shell color scheme default value */
        $shell_cs = 'light';

        /* check view style cookie */
        if (!empty($_COOKIE['jkd-shell-view'])):

            /* shell view cookie value */
            $shell_view = $_COOKIE['jkd-shell-view'];

        endif;

        /* check color scheme cookie */
        if (!empty($_COOKIE['jkd-shell-cs'])):

            /* shell color scheme cookie value */
            $shell_cs = $_COOKIE['jkd-shell-cs'];

        endif;

        /* shell view class */
        array_push($classes, $shell_view . '-view');

        /* shell color scheme class */
        array_push($classes, $shell_cs . '-cs');

        /* classes array to string */
        $classes = implode(' ', $classes);

        ?>

        <!-- ADMIN SHELL START -->

        <main class="jkd-admin-wrapper <?php echo esc_attr($classes); ?>"
            <?php if (!empty($args['slug'])): ?>
                data-action="<?php echo esc_attr($args['slug']); ?>"
            <?php endif; ?>
              data-current-tab="<?php echo esc_attr($current_tab); ?>">

            <!-- INNER WRAPPER START -->

            <div class="admin-inner-wrapper">

                <!-- ADMIN HEADER START -->

                <div class="admin-header">

                    <?php if (!empty($args['logo_svg'])): ?>

                        <!-- LOGOTYPE START -->

                        <div class="logotype-wrapper">

                            <?php echo _($args['logo_svg']); ?>

                        </div>

                        <!-- LOGOTYPE END -->

                    <?php endif; ?>

                    <!-- TITLE WRAPPER START -->

                    <div class="title-wrapper">

                        <!-- PAGE TITLE START -->

                        <h5 class="page-title">

                            <?php if (!empty($args['name'])): ?>

                                <!-- TITLE START -->

                                <span class="title">

                                        <?php echo esc_html($args['name']); ?>

                                    </span>

                                <!-- TITLE END -->

                            <?php endif; ?>

                            <?php if (!empty($args['version'])): ?>

                                <!-- VERSION START -->

                                <span class="version">

                                        <?php echo esc_html('ver ' . $args['version']); ?>

                                    </span>

                                <!-- VERSION END -->

                            <?php endif; ?>

                        </h5>

                        <!-- PAGE TITLE END -->

                    </div>

                    <!-- TITLE WRAPPER END -->

                    <?php if (!empty($args['additional_links'])): ?>

                        <!-- RIGHT SIDE START -->

                        <div class="right-side">

                            <!-- ADDITIONAL LINKS START -->

                            <ul class="additional-links">

                                <?php

                                /* additional links loop */
                                foreach ($args['additional_links'] as $link):

                                    /* check if core elements is not empty */
                                    if (!empty($link['title'])
                                        && !empty($link['url'])
                                        && !empty($link['icon'])):

                                        ?>

                                        <!-- LINK ITEM START -->

                                        <li class="link-item">

                                            <!-- LINK START -->

                                            <a href="<?php echo esc_url($link['url']); ?>"
                                               target="_blank"
                                               data-tipy-placement="top"
                                               data-tippy-content="<?php echo esc_html($link['title']); ?>">

                                                <?php if (!empty($link['icon'])): ?>

                                                    <!-- LINK ICON START -->

                                                    <i class="<?php echo esc_attr($link['icon']) ?>"></i>

                                                    <!-- LINK ICON END -->

                                                <?php endif; ?>

                                            </a>

                                            <!-- LINK END -->

                                        </li>

                                        <!-- LINK ITEM END -->

                                    <?php

                                    endif;

                                endforeach;

                                ?>

                            </ul>

                            <!-- ADDITIONAL LINKS END -->

                        </div>

                        <!-- RIGHT SIDE END -->

                    <?php endif; ?>

                </div>

                <!-- ADMIN HEADER END -->

                <!-- ADMIN BODY START -->

                <div class="admin-body">

                    <!-- BODY INNER START -->

                    <div class="body-inner">

                        <!-- TABS HEADER START -->

                        <ul class="tabs-header">

                            <?php

                            if ($activation && !empty($args['tabs'])):

                                foreach ($args['tabs'] as $key => $tab): ?>

                                    <!-- TAB ITEM START -->

                                    <li class="tab-item <?php if ($current_tab === $key): echo esc_attr('active'); endif; ?>"
                                        data-tab="<?php echo esc_attr($key); ?>">

                                        <?php echo esc_html($tab); ?>

                                    </li>

                                    <!-- TAB ITEM END -->

                                <?php

                                endforeach;

                            else:

                                ?>

                                <!-- TAB ITEM START -->

                                <li class="tab-item active" data-tab="license">

                                    <?php echo esc_html__('License', 'qreatix'); ?>

                                </li>

                                <!-- TAB ITEM END -->

                            <?php endif; ?>

                            <!-- SHELL SETTINGS TOGGLE START -->

                            <li class="shell-setting-toggle tab-item <?php if ($current_tab === 'shell-settings'): echo esc_attr('active'); endif; ?>"
                                data-tipy-placement="top"
                                data-tippy-content="<?php echo esc_html__('Shell Settings', 'qreatix'); ?>"
                                data-tab="<?php echo esc_attr('shell-settings'); ?>">

                                <!-- SETTINGS ICON START -->

                                <i class="ri-settings-4-line"></i>

                                <!-- SETTINGS ICON END -->

                            </li>

                            <!-- SHELL SETTINGS TOGGLE END -->

                        </ul>

                        <!-- TABS HEADER END -->

                        <?php

                        /* check notices callback */
                        if (!empty($args['notices_callback'])):

                            /* call notices callback */
                            call_user_func($args['notices_callback']);

                        endif;

                        if (!$activation):

                            Helper::add_alert(array(
                                'slug' => 'not-activated',
                                'type' => 'danger',
                                'title' => esc_html__('Warning! ', 'qreatix') . $this->getInstance()->name . esc_html__(' is not activated!', 'qreatix'),
                                'description' => esc_html__('To use ', 'qreatix') . $this->getInstance()->name . esc_html__(' and all its features, please activate it with your Envato License.', 'qreatix'),
                                'icon' => 'ri-error-warning-line',
                                'border' => 'bottom',
                            ));

                        endif;

                        if (!empty($activation_data) && !empty($activation_data->supported_until)):

                            /* support until */
                            $supported_until = new DateTime($activation_data->supported_until);

                            /* current date */
                            $current_date = new DateTime(date('Y-m-d-G'));

                            /* if current date > supported until */
                            if ($current_date > $supported_until):

                                /* Expired support alert */
                                \jkdevkit\Helper::add_alert(array(
                                    'slug' => 'support-expired',
                                    'type' => 'danger',
                                    'title' => esc_html__('Your support period has expired', 'qreatix'),
                                    'description' => esc_html__('You will no longer receive ', 'qreatix') . esc_html($args['name']) . esc_html__(' support and our auto-updates'),
                                    'icon' => 'ri-error-warning-line',
                                    'border' => 'bottom',
                                    'renew_guide_title' => esc_html__('How To Renew Support?', 'qreatix'),
                                    'renew_guide' => esc_url('https://help.market.envato.com/hc/en-us/articles/207886473-Extending-and-Renewing-Item-Support'),
                                    'renew_link_title' => esc_html__('Renew Your Support', 'qreatix'),
                                    'renew_link' => esc_url($args['item_url']),
                                ));

                            endif;

                        endif;

                        ?>

                        <!-- CURRENT CONTENT START -->

                        <div class="current-content">

                            <?php

                            /* render current tab */
                            if (!empty($this->getInstance()->tabs_callback)):

                                $this->getInstance()->tabs_manager->tab_render($current_tab, $this->getInstance()->tabs_callback);

                            else:

                                $this->getInstance()->tabs_manager->tab_render($current_tab);

                            endif;

                            ?>

                        </div>

                        <!-- CURRENT CONTENT END -->

                    </div>

                    <!-- BODY INNER END -->

                    <!-- HELP UKRAINE START -->

                    <div class="help-ukraine-banner">

                        <!-- UKRAINE FLAG START -->

                        <div class="ukraine-flag">

                            <!-- BLUE COLOR START -->

                            <span class="blue"></span>

                            <!-- BLUE COLOR END -->

                            <!-- YELLOW COLOR START -->

                            <span class="yellow"></span>

                            <!-- YELLOW COLOR END -->

                        </div>

                        <!-- UKRAINE FLAG END -->

                        <!-- HELP MESSAGE START -->

                        <div class="help-message">

                            <?php echo esc_html__('We live in Ukraine, please help us protect our country from Russian invaders!', 'qreatix'); ?>

                            <!-- BANK LINK START -->

                            <a href="https://bank.gov.ua/en/news/all/natsionalniy-bank-vidkriv-spetsrahunok-dlya-zboru-koshtiv-na-potrebi-armiyi?fbclid=IwAR1lNXX4dFr6DV4_JkLKLC3PclNdiRCXnVfxJMi-uwnrH24ITQTiNNG0UxI">

                                <?php echo esc_html__('Raise Funds for Ukraine’s Armed Forces', 'qreatix'); ?>

                            </a>

                            <!-- BANK LINK END -->

                        </div>

                        <!-- HELP MESSAGE END -->

                    </div>

                    <!-- HELP UKRAINE END -->

                </div>

                <!-- ADMIN BODY END -->

                <!-- ADMIN FOOTER START -->

                <div class="admin-footer">

                    <!-- FOOTER INNER START -->

                    <div class="footer-inner">

                        <?php if (!empty($args['copyright'])
                            && !empty($args['author'])
                            && !empty($args['author_url'])): ?>

                            <!-- COPYRIGHT START -->

                            <p class="copyright">

                                <!-- COPYRIGHT TITLE START -->

                                <span class="copyright-title">

                                        <?php echo esc_html($args['copyright'] . ' by '); ?>

                                    </span>

                                <!-- COPYRIGHT TITLE END -->

                                <!-- AUTHOR URL START -->

                                <a href="<?php echo esc_url($args['author_url']) ?>" class="author-url">

                                    <?php echo esc_html($args['author']); ?>

                                </a>

                                <!-- AUTHOR URL END -->

                            </p>

                            <!-- COPYRIGHT END -->

                        <?php endif; ?>

                        <?php if (!empty($args['version'])): ?>

                            <!-- RIGHT SIDE START -->

                            <div class="right-side">

                                <?php if (!empty($args['social_links'])): ?>

                                    <!-- SOCIAL LIST START -->

                                    <ul class="social-list">

                                        <?php foreach ($args['social_links'] as $link): ?>

                                            <?php if (!empty($link['url']) && !empty($link['icon'])): ?>

                                                <!-- SOCIAL ITEM START -->

                                                <li class="social-item">

                                                    <!-- SOCIAL LINK START -->

                                                    <a href="<?php echo esc_attr($link['url']); ?>"
                                                       target="_blank"
                                                       data-tipy-placement="top"
                                                       data-tippy-content="<?php echo esc_html($link['title']); ?>">

                                                        <!-- SOCIAL ICON START -->

                                                        <i class="<?php echo esc_attr($link['icon']); ?>"></i>

                                                        <!-- SOCIAL ICON END -->

                                                    </a>

                                                    <!-- SOCIAL LINK END -->

                                                </li>

                                                <!-- SOCIAL ITEM END -->

                                            <?php endif; ?>

                                        <?php endforeach; ?>

                                    </ul>

                                    <!-- SOCIAL LIST END -->

                                <?php endif; ?>

                                <!-- VERSION START -->

                                <p class="version">

                                    <?php echo esc_html__('Powered by jkdevkit v' . $this->getJkdVersion()); ?>

                                </p>

                                <!-- VERSION END -->

                            </div>

                            <!-- RIGHT SIDE END -->

                        <?php endif; ?>

                    </div>

                    <!-- FOOTER INNER END -->

                </div>

                <!-- ADMIN FOOTER END -->

            </div>

            <!-- INNER WRAPPER END -->

        </main>

        <!-- ADMIN SHELL END -->

        <?php

    }

}
