<?php

namespace jkdevkit;

use \DateTime;

defined('ABSPATH') || exit;

class Tabs_Manager extends \jkdevkit
{

    /**
     * @var
     */
    public $instance;

    /**
     * @return mixed
     */
    public function getInstance()
    {
        return $this->instance;
    }

    /**
     * @param $instance
     *
     * @return void
     */
    public function setInstance($instance): void
    {
        $this->instance = $instance;
    }

    /**
     * @param $instance
     */
    public function __construct($instance)
    {

        $this->setInstance($instance);

        $this->init_ajax();

    }

    /**
     * @return void
     */
    public function init_ajax()
    {

        /* ajax tabs switcher handler */
        add_action('wp_ajax_nopriv_jkd_tabs_switcher_' . $this->getInstance()->slug . '_handler', [$this, 'tabs_switcher']);
        add_action('wp_ajax_jkd_tabs_switcher_' . $this->getInstance()->slug . '_handler', [$this, 'tabs_switcher']);

    }

    /**
     * @return void
     */
    public function tabs_switcher()
    {

        /* get tab */
        $tab = $_POST['tab'];

        /* check if tab is not empty */
        if (!empty($tab)):

            /* render tab content */
            $this->tab_render($tab, $this->getInstance()->tabs_callback);

        endif;

        /* end */
        die();

    }

    /**
     * @param $tab
     * @param mixed $custom_tabs
     *
     * @return void
     */
    public function tab_render($tab, $custom_tabs = false)
    {

        /* output default tabs */
        $this->default_tabs($tab);

        if ($custom_tabs):

            /* call tabs callback */
            call_user_func($custom_tabs, $tab);

        endif;

    }

    /**
     * @param string $tab
     *
     * @return void
     */
    public function default_tabs(string $tab = '')
    {

        /* tab slug checker */
        if ($tab === 'license'):

            /* get activation check */
            $activation = $this->getInstance()->isActivation();

            /* check activation */
            if ($activation):

                /* get activation data */
                $activation_data = $this->getInstance()->getActivationData();

                /* if true - render license info wrapper */
                $this->license_tab($activation_data);

            else:

                /* if false - render registration form */
                $this->registration_form_tab();

            endif;

        /* changelog tab */
        elseif ($tab === 'changelog'):

            /* render changelog */
            $this->changelog_tab();

        /* fonts tab */
        elseif ($tab === 'fonts'):

            /* render fonts */
            $this->fonts_tab();

        /* tools tab */
        elseif ($tab === 'tools'):

            /* render tools */
            $this->tools_tab();

        /* status tab */
        elseif ($tab === 'status'):

            /* render status */
            $this->status_tab();

        /* shell settings tab */
        elseif ($tab === 'shell-settings'):

            /* render shell settings */
            $this->shell_settings_tab();

        endif;

    }

    /**
     * @return void
     */
    public function tools_tab()
    {

        /* get all jkd settings (only slugs) */
        $settings = get_option('jkd_all_settings');

        ?>

        <!-- TOOLS WRAPPER START -->

        <div class="tools settings-wrapper">

            <!-- TOOLS INNER START -->

            <div class="tools-inner">

                <?php

                /* settings section */
                Controls_Manager::add_setting(array(
                    'type' => 'divider',
                    'slug' => 'section-settings-tool',
                    'label' => esc_html__('Settings', 'qreatix'),
                ));

                ?>

                <div class="setting-part">

                    <h6 class="setting-title">

                        <?php echo esc_html__('Import Settings', 'qreatix'); ?>

                    </h6>

                    <p class="setting-description">

                        <?php echo esc_html__('To import your settings just click this button, select your .JSON settings file and confirm the import.', 'qreatix'); ?>

                    </p>

                    <!-- import button -->
                    <button class="open-form-button action-button jkd-button wp-style size-ui animation-fade">

                        <i class="ri-download-2-line left-icon"></i>

                        <?php echo esc_html__('Import Settings', 'qreatix'); ?>

                    </button>

                </div>

                <div class="setting-part">

                    <h6 class="setting-title">

                        <?php echo esc_html__('Export Settings', 'qreatix'); ?>

                    </h6>

                    <p class="setting-description">

                        <?php echo esc_html__('To export your settings just click this button and you will automatically download a .JSON file with all your settings.', 'qreatix'); ?>

                    </p>

                    <!-- export button -->
                    <button class="action-button export-button jkd-button wp-style size-ui animation-fade <?php if (empty($settings)): ?>disabled<?php endif; ?>">

                            <span class="static-text">

                                 <i class="ri-upload-2-line left-icon"></i>

                                <?php echo esc_html__('Export Settings', 'qreatix'); ?>

                            </span>

                        <span class="loading-text">

                                <?php echo esc_html__('Loading', 'qreatix'); ?>

                                <?php Helper::loader_render(); ?>

                           </span>

                    </button>

                </div>

                <div class="setting-part">

                    <h6 class="setting-title">

                        <?php echo esc_html__('Reset Settings', 'qreatix'); ?>

                    </h6>

                    <p class="setting-description">

                        <?php echo esc_html__('To reset all your settings to default, just click this button and confirm your action', 'qreatix'); ?>

                    </p>

                    <!-- reset button -->
                    <button class="action-button reset-all-button jkd-button danger-style size-ui animation-fade <?php if (empty($settings)): ?>disabled<?php endif; ?>">

                            <span class="static-text">

                                <i class="ri-delete-bin-line left-icon"></i>

                                <?php echo esc_html__('Reset Settings', 'qreatix'); ?>

                            </span>

                        <span class="loading-text">

                                 <?php echo esc_html__('Loading', 'qreatix'); ?>

                                 <?php Helper::loader_render(); ?>

                           </span>

                    </button>

                </div>

                <?php

                /* meta settings */
                Controls_Manager::add_setting(array(
                    'type' => 'divider',
                    'slug' => 'section-meta-tool',
                    'label' => esc_html__('Meta', 'qreatix'),
                ));

                ?>

                <div class="setting-part">

                    <h6 class="setting-title">

                        <?php echo esc_html__('Update Meta', 'qreatix'); ?>

                    </h6>

                    <p class="setting-description">

                        <?php echo esc_html__('Using this button you can update your metadata (changelog, news etc)', 'qreatix'); ?>

                    </p>

                    <!-- update meta button -->
                    <button class="jkd-button wp-style size-ui animation-fade update-meta">

                            <span class="static-text">

                                <i class="ri-git-branch-line left-icon"></i>

                                <?php echo esc_html__('Update Meta', 'qreatix'); ?>

                            </span>

                        <span class="loading-text">

                                <?php echo esc_html__('Loading', 'qreatix'); ?>

                                <?php Helper::loader_render(); ?>

                            </span>

                    </button>

                </div>

                <div class="setting-part">

                    <h6 class="setting-title">

                        <?php echo esc_html__('Update License', 'qreatix'); ?>

                    </h6>

                    <p class="setting-description">

                        <?php echo esc_html__('Using this button you can update your license information', 'qreatix'); ?>

                    </p>

                    <!-- update license button -->
                    <button class="jkd-button envato-style size-ui animation-fade update-license-info">

                            <span class="static-text">

                                <i class="ri-database-2-line left-icon"></i>

                                <?php echo esc_html__('Update License', 'qreatix'); ?>

                            </span>

                        <span class="loading-text">

                                <?php echo esc_html__('Loading', 'qreatix'); ?>

                                <?php Helper::loader_render(); ?>

                            </span>

                    </button>

                </div>

                <div class="setting-part">

                    <h6 class="setting-title">

                        <?php echo esc_html__('Deregister Domain', 'qreatix'); ?>

                    </h6>

                    <p class="setting-description">

                        <?php echo esc_html__('To reset all your settings to default, just click this button and confirm your action', 'qreatix'); ?>

                    </p>

                    <!-- remove license button -->
                    <button class="jkd-button danger-style size-ui animation-fade deactivation-button">

                        <i class="ri-link-unlink left-icon"></i>

                        <?php echo esc_html__('Deregister Domain', 'qreatix'); ?>

                    </button>

                </div>

            </div>

            <!-- TOOLS INNER END -->

            <!-- IMPORT FORM OVERLAY START -->

            <div class="import-form-overlay">

                <div class="import-form-popup">

                    <i class="ri-close-line close-button"></i>

                    <div class="popup-header">

                        <?php echo esc_html__('Settings Importer', 'qreatix'); ?>

                    </div>

                    <div class="popup-body">

                        <!-- import settings form -->
                        <form class="import-settings-form" method="post" enctype="multipart/form-data"
                              autocomplete="off">

                            <input type="file" name="file" class="file-input hidden-input" accept="application/JSON"
                                   id="file"/>

                            <!-- select file button -->
                            <div class="action-button select-button jkd-button wp-border-style size-ui"
                                 data-success-text="<?php echo esc_attr__('Done!', 'qreatix'); ?>"
                                 data-loading-text="<?php echo esc_attr__('Importing', 'qreatix'); ?>">

                                <?php echo esc_html__('Select File', 'qreatix'); ?>

                            </div>

                            <!-- submit button -->
                            <button value="upload" type="submit"
                                    class="action-button import-button disabled jkd-button wp-style size-ui"
                                    data-success-text="<?php echo esc_attr__('Done!', 'qreatix'); ?>"
                                    data-loading-text="<?php echo esc_attr__('Importing', 'qreatix'); ?>">

                            <span class="text">

                                <?php echo esc_html__('Import Settings', 'qreatix'); ?>

                            </span>

                                <?php Helper::loader_render(); ?>

                                <i class="ri-check-line success-icon"></i>

                            </button>

                        </form>

                    </div>

                </div>

            </div>

            <!-- IMPORT FORM OVERLAY END -->

        </div>

        <!-- TOOLS WRAPPER END -->

        <?php

    }

    /**
     * @return void
     */
    public function status_tab()
    {

        ?>

        <!-- status wrapper -->
        <div class="status-wrapper settings-wrapper">

            <div class="setting-part">

                <?php

                /* get php info array */
                $phpinfo = Helper::phpinfo_array();

                /* check if php info array is not empty */
                if (!empty($phpinfo)):

                    /* core */
                    $core = $phpinfo['Core'];

                    /* curl */
                    $curl = $phpinfo['curl'];

                    /* curl support */
                    $curl_support = $curl['cURL support'];

                    /* php version */
                    $php_version = $core['PHP Version'];

                    /* max_execution_time */
                    $max_execution_time = $core['max_execution_time'];

                    /* max_file_uploads */
                    $max_file_uploads = $core['max_file_uploads'];

                    /* max_input_time */
                    $max_input_time = $core['max_input_time'];

                    /* memory_limit */
                    $memory_limit = $core['memory_limit'];

                    /* post_max_size */
                    $post_max_size = $core['post_max_size'];

                    /* upload_max_filesize */
                    $upload_max_filesize = $core['upload_max_filesize'];

                endif;

                /* get loaded extensions */
                $extensions = get_loaded_extensions();

                /* check if php info array or extensions is not empty */
                if (!empty($phpinfo) || !empty($extensions)):

                    /* server info section */
                    Controls_Manager::add_setting(array(
                        'type' => 'divider',
                        'slug' => 'section-server-info',
                        'label' => esc_html__('Server Info', 'qreatix'),
                    ));

                    ?>

                    <ul class="server-info">

                        <?php if (!empty($phpinfo)): ?>

                            <li class="info-item <?php if (!version_compare($php_version, '7.4', '>=')): echo esc_attr('not-fit'); else: echo esc_attr('fits'); endif; ?>">

                                <div class="info-name">

                                    <i class="ri-check-line fits-icon"></i>

                                    <i class="ri-close-line not-fit-icon"></i>

                                    <?php echo esc_html__('PHP Version', 'qreatix'); ?>

                                </div>

                                <div class="info-value">

                                    <?php echo esc_html($php_version); ?>

                                </div>

                            </li>

                            <li class="info-item <?php if ($curl_support !== 'enabled'): echo esc_attr('not-fit'); else: echo esc_attr('fits'); endif; ?>">

                                <div class="info-name">

                                    <i class="ri-check-line fits-icon"></i>

                                    <i class="ri-close-line not-fit-icon"></i>

                                    <?php echo esc_html__('Curl Support', 'qreatix'); ?>

                                </div>

                                <div class="info-value">

                                    <?php echo esc_html($curl_support); ?>

                                </div>

                            </li>

                            <li class="info-item <?php if ($max_execution_time[0] < 30): echo esc_attr('not-fit'); else: echo esc_attr('fits'); endif; ?>">

                                <div class="info-name">

                                    <i class="ri-check-line fits-icon"></i>

                                    <i class="ri-close-line not-fit-icon"></i>

                                    <?php echo esc_html__('Max Execution Time', 'qreatix'); ?>

                                </div>

                                <div class="info-value">

                                    <?php echo esc_html($max_execution_time[0]); ?>

                                </div>

                            </li>

                            <li class="info-item <?php if ($max_file_uploads[0] < 64): echo esc_attr('not-fit'); else: echo esc_attr('fits'); endif; ?>">

                                <div class="info-name">

                                    <i class="ri-check-line fits-icon"></i>

                                    <i class="ri-close-line not-fit-icon"></i>

                                    <?php echo esc_html__('Max File Uploads', 'qreatix'); ?>

                                </div>

                                <div class="info-value">

                                    <?php echo esc_html($max_file_uploads[0]); ?>

                                </div>

                            </li>

                            <li class="info-item <?php if ($max_input_time[0] < 60): echo esc_attr('not-fit'); else: echo esc_attr('fits'); endif; ?>">

                                <div class="info-name">

                                    <i class="ri-check-line fits-icon"></i>

                                    <i class="ri-close-line not-fit-icon"></i>

                                    <?php echo esc_html__('Max Input Time', 'qreatix'); ?>

                                </div>

                                <div class="info-value">

                                    <?php echo esc_html($max_input_time[0]); ?>

                                </div>

                            </li>

                            <li class="info-item <?php if ((int)str_replace('M', '', $memory_limit[0]) < 64): echo esc_attr('not-fit'); else: echo esc_attr('fits'); endif; ?>">

                                <div class="info-name">

                                    <i class="ri-check-line fits-icon"></i>

                                    <i class="ri-close-line not-fit-icon"></i>

                                    <?php echo esc_html__('Memory Limit', 'qreatix'); ?>

                                </div>

                                <div class="info-value">

                                    <?php echo esc_html($memory_limit[0]); ?>

                                </div>

                            </li>

                            <li class="info-item <?php if ((int)str_replace('M', '', $memory_limit[0]) < 8): echo esc_attr('not-fit'); else: echo esc_attr('fits'); endif; ?>">

                                <div class="info-name">

                                    <i class="ri-check-line fits-icon"></i>

                                    <i class="ri-close-line not-fit-icon"></i>

                                    <?php echo esc_html__('Post Max Size', 'qreatix'); ?>

                                </div>

                                <div class="info-value">

                                    <?php echo esc_html($post_max_size[0]); ?>

                                </div>

                            </li>

                            <li class="info-item <?php if ((int)str_replace('M', '', $memory_limit[0]) < 32): echo esc_attr('not-fit'); else: echo esc_attr('fits'); endif; ?>">

                                <div class="info-name">

                                    <i class="ri-check-line fits-icon"></i>

                                    <i class="ri-close-line not-fit-icon"></i>

                                    <?php echo esc_html__('Upload Max Filesize', 'qreatix'); ?>

                                </div>

                                <div class="info-value">

                                    <?php echo esc_html($upload_max_filesize[0]); ?>

                                </div>

                            </li>

                        <?php

                        endif;

                        if (!empty($extensions) && !empty($this->getInstance()->reqext)):

                            foreach ($this->getInstance()->reqext as $ext):

                                ?>

                                <li class="info-item <?php if (!in_array($ext, $extensions)): echo esc_attr('not-fit'); else: echo esc_attr('fits'); endif; ?>">

                                    <div class="info-name">

                                        <i class="ri-check-line fits-icon"></i>

                                        <i class="ri-close-line not-fit-icon"></i>

                                        <?php echo esc_html('php ' . $ext); ?>

                                    </div>

                                    <div class="info-value">

                                        <?php if (!in_array($ext, $extensions)): echo esc_html__('not installed', 'qreatix'); else: echo esc_attr('installed'); endif; ?>

                                    </div>

                                </li>

                            <?php

                            endforeach;

                        endif;

                        ?>

                    </ul>

                <?php

                else:

                    /* if server info is not loaded */
                    Helper::add_alert(array(
                        'slug' => 'no-info',
                        'type' => 'warning',
                        'title' => esc_html__('Information is not available.', 'qreatix'),
                        'description' => esc_html__('Unfortunately, we were unable to get up-to-date information about your server.', 'qreatix'),
                        'icon' => 'ri-error-warning-line',
                        'border' => 'top'
                    ));

                endif;

                ?>

            </div>

            <?php

            /* templates folder */
            $templates_folder = dirname(__FILE__, 2) . '/templates/';

            /* if custom templates path is not empty */
            if (!empty($this->getInstance()->templates_path)):

                /* set custom templates folder */
                $templates_folder = $this->getInstance()->templates_path;

            endif;

            /* templates parser */
            if (file_exists($templates_folder)):

                /* get content of the templates folder */
                $dir_contents = Helper::get_dir_contents($templates_folder);

                if (!empty($dir_contents)):

                    ?>

                    <div class="setting-part templates-listing">

                        <?php

                        Controls_Manager::add_setting(array(
                            'type' => 'divider',
                            'slug' => 'section-templates',
                            'label' => esc_html__('Templates', 'qreatix'),
                        ));

                        ?>

                        <ul class="templates-list depth-1">

                            <?php

                            foreach ($dir_contents as $content):

                                $parent_dir = basename(dirname($content));

                                $file_name = basename($content);

                                if ($parent_dir === basename($templates_folder)):

                                    if (!is_dir($content)):

                                        ?>

                                        <li class="template-item">

                                            <i class="ri-file-text-line"></i>

                                            <?php echo esc_html($file_name); ?>

                                        </li>

                                    <?php

                                    else:

                                        $sub_items = Helper::get_dir_contents($content);

                                        ?>

                                        <li class="template-item dir-item">

                                            <i class="ri-folder-fill"></i>

                                            <?php echo esc_html($file_name); ?>

                                            <?php if (!empty($sub_items)): ?>

                                                <ul class="templates-list depth-2">

                                                    <?php foreach ($sub_items as $sub_content):

                                                        $file_name = basename($sub_content);

                                                        ?>

                                                        <li class="template-item">

                                                            <i class="ri-file-text-line"></i>

                                                            <?php echo esc_html($file_name); ?>

                                                        </li>

                                                    <?php endforeach; ?>

                                                </ul>

                                            <?php

                                            endif;

                                            ?>

                                        </li>

                                    <?php endif;

                                endif;

                            endforeach;

                            ?>

                        </ul>

                    </div>

                <?php

                endif;

            endif;

            ?>

        </div>

        <?php

    }

    /**
     * @return void
     */
    public function registration_form_tab()
    {

        ?>

        <!-- registration form -->
        <div class="registration-form">

            <!-- steps wrapper -->
            <div class="steps-wrapper">

                <!-- step wrapper -->
                <div class="step-wrapper">

                    <!-- step counter -->
                    <p class="step-counter">

                        <?php echo esc_html('01'); ?>

                    </p>

                    <!-- step title -->
                    <h6 class="step-title">

                        <?php echo esc_html__('Start Registration', 'qreatix'); ?>

                    </h6>

                    <!-- step description -->
                    <p class="step-desc">

                        <?php echo esc_html__('To start the registration process just click on the button below', 'qreatix'); ?>

                        <i class="ri-arrow-down-line"></i>

                    </p>

                    <!-- start registration -->
                    <div class="start-registration">

                        <!-- activation button -->
                        <button class="jkd-button size-extra-small envato-style envato-activation-button">

                            <svg class="envato-logo left-icon" version="1.1"
                                 xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"
                                 x="0px"
                                 y="0px" viewBox="0 0 107.7 122.9" style="enable-background:new 0 0 107.7 122.9;"
                                 xml:space="preserve">
                                <path style="fill: #FFFFFF;" class="st0" d="M91.8,1c-3.6-2-13.9-0.8-26.3,3c-21.7,14.8-40,36.7-41.3,71.8c-0.2,0.8-2.4-0.1-2.8-0.4
	c-5.9-11.2-8.2-23.1-3.3-40.1c0.9-1.5-2.1-3.4-2.6-2.8c-3.2,3.3-6.1,7-8.5,11C-7.8,69,1.8,101.8,27.6,116.1
	c25.8,14.4,58.3,5.1,72.7-20.7c0,0,0,0,0,0C116.9,65.7,101.5,6.4,91.8,1z"/></svg>

                            <?php echo esc_html__('Activate License', 'qreatix'); ?>

                        </button>

                    </div>

                </div>

                <!-- step wrapper -->
                <div class="step-wrapper">

                    <!-- step counter -->
                    <p class="step-counter">

                        <?php echo esc_html('02'); ?>

                    </p>

                    <!-- step title -->
                    <h6 class="step-title">

                        <?php echo esc_html__('Authorization', 'qreatix'); ?>

                    </h6>

                    <!-- step description -->
                    <p class="step-desc">

                        <?php echo esc_html__('Login with Your Envato Account and connect it with our app.', 'qreatix'); ?>

                    </p>

                </div>

                <!-- step wrapper -->
                <div class="step-wrapper">

                    <!-- step counter -->
                    <p class="step-counter">

                        <?php echo esc_html('03'); ?>

                    </p>

                    <!-- step title -->
                    <h6 class="step-title">

                        <?php echo esc_html__('Activation Process', 'qreatix'); ?>

                    </h6>

                    <!-- step description -->
                    <p class="step-desc">

                        <?php echo esc_html__('Make sure all the data is correct and click the Proceed Activation button.', 'qreatix'); ?>

                    </p>

                </div>

                <!-- step wrapper -->
                <div class="step-wrapper">

                    <!-- step counter -->
                    <p class="step-counter success">

                        <i class="ri-check-line"></i>

                    </p>

                    <!-- step title -->
                    <h6 class="step-title">

                        <?php echo esc_html__('Done!', 'qreatix'); ?>

                    </h6>

                    <!-- step description -->
                    <p class="step-desc">

                        <?php echo esc_html__('Now you can start use ', 'qreatix') . $this->getInstance()->name . __(' functionality.', 'qreatix'); ?>

                    </p>

                </div>

            </div>

        </div>

        <?php

    }

    /**
     * @param $data
     *
     * @return void
     * @throws \Exception
     */
    public function license_tab($data)
    {

        /* check $data arg */
        if (empty($data)):

            /* get license data */
            $data = $this->getActivationData();

        endif;

        if (!empty($data)):

            /* current date */
            $current_date = new DateTime(date('Y-m-d-G'));

            if (!empty($data->sold_at)):

                /* item sold date */
                $sold_at = new DateTime($data->sold_at);

            endif;

            if (!empty($data->supported_until)):

                /* item support date */
                $supported_until = new DateTime($data->supported_until);

            endif;

            /* item status */
            $status = !empty($data->status) ? $data->status : _('unknown');

            /* item domain */
            $domain = !empty($data->domain) ? $data->domain : _('unknown');

            /* item id */
            $id = !empty($data->id) ? $data->id : 'unknown';

            /* item license type */
            $license_type = !empty($data->license) ? $data->license : 'unknown';

            /* item activations left */
            $activations_left = !empty($data->activations_left) ? $data->activations_left : 0;

            /* purchase code */
            $code = !empty($data->code) ? $data->code : 'unknown';

            /* last verification check */
            $last_check = get_option($this->getInstance()->slug . '_jkd_domain_verification_check');

            /* set expired status */
            if (!empty($supported_until) && $current_date > $supported_until):

                /* expired status */
                $status = 'expired';

            endif;

            ?>

            <!-- license info -->
            <div class="license-info"
                 <?php if (!empty($code)): ?>data-purchase-code="<?php echo esc_attr($code); ?><?php endif; ?>">

                <!-- info list -->
                <ul class="info-list">

                    <?php if (!empty($status)): ?>

                        <!-- info item -->
                        <li class="info-item">

                            <!-- info -->
                            <div class="info">

                                <?php echo esc_html__('Status:', 'qreatix'); ?>

                            </div>

                            <!-- value -->
                            <div class="value">

                                <?php

                                /* if status === activated */
                                if ($status === 'activated'):

                                    ?>

                                    <!-- status-label -->
                                    <p class="status-label activated">

                                        <!-- status dot -->
                                        <span class="dot"></span>

                                        <?php

                                        /* output status */
                                        echo esc_html__('Activated', 'qreatix');

                                        ?>

                                    </p>

                                <?php

                                /* if status === not activated */
                                elseif ($status === 'not-activated'):

                                    ?>

                                    <!-- status-label -->
                                    <p class="status-label not-activated">

                                        <!-- status dot -->
                                        <span class="dot"></span>

                                        <?php

                                        /* output status */
                                        echo esc_html__('Not Activated', 'qreatix');

                                        ?>

                                    </p>

                                <?php

                                /* if status === expired */
                                elseif ($status === 'expired'):

                                    ?>

                                    <!-- status-label -->
                                    <p class="status-label expired">

                                        <!-- status dot -->
                                        <span class="dot"></span>

                                        <?php

                                        /* output status */
                                        echo esc_html__('Expired', 'qreatix');

                                        ?>

                                    </p>

                                <?php

                                /* if status === unknown */
                                elseif ($status === 'unknown'):

                                    ?>

                                    <!-- status-label -->
                                    <p class="status-label expired">

                                        <!-- status dot -->
                                        <span class="dot"></span>

                                        <?php

                                        /* output status */
                                        echo esc_html__('Unknown', 'qreatix');

                                        ?>

                                    </p>

                                <?php endif; ?>

                            </div>

                        </li>

                    <?php endif; ?>

                    <?php if (!empty($id)): ?>

                        <!-- info-item -->
                        <li class="info-item">

                            <!-- info -->
                            <div class="info">

                                <?php echo esc_html__('Item ID:', 'qreatix'); ?>

                            </div>

                            <!-- value -->
                            <div class="value">

                                <strong><?php echo esc_html($id); ?></strong>

                            </div>

                        </li>

                    <?php endif; ?>

                    <?php if (!empty($code)): ?>

                        <!-- info-item -->
                        <li class="info-item">

                            <!-- info -->
                            <div class="info">

                                <?php echo esc_html__('License Key:', 'qreatix'); ?>

                            </div>

                            <!-- value -->
                            <div class="value">

                                <strong><?php echo esc_html($code); ?></strong>

                                <span class="license-type">

                                        <?php echo esc_html('(' . $license_type . ')'); ?>

                                    </span>

                            </div>

                        </li>

                    <?php endif; ?>

                    <?php if (!empty($sold_at)): ?>

                        <!-- info-item -->
                        <li class="info-item">

                            <!-- info -->
                            <div class="info">

                                <?php echo esc_html__('Sold At:', 'qreatix'); ?>

                            </div>

                            <!-- value -->
                            <div class="value">

                                <?php echo esc_html($sold_at->format('Y-m-d')); ?>

                            </div>

                        </li>

                    <?php endif; ?>

                    <?php if (!empty($supported_until)): ?>

                        <!-- info-item -->
                        <li class="info-item">

                            <!-- info -->
                            <div class="info">

                                <?php echo esc_html__('Support Expire Date:', 'qreatix'); ?>

                            </div>

                            <!-- value -->
                            <div class="value">

                                <?php if ($current_date > $supported_until): ?>

                                    <span class="expired-message">

                                            <?php echo esc_html__('Expired ', 'qreatix') . esc_html('(' . $supported_until->format('Y-m-d') . ')'); ?>

                                        </span>

                                <?php else: ?>

                                    <?php echo esc_html($supported_until->format('Y-m-d')); ?>

                                <?php endif; ?>

                            </div>

                        </li>

                    <?php endif; ?>

                    <?php if (!empty($domain)): ?>

                        <!-- info-item -->
                        <li class="info-item">

                            <!-- info -->
                            <div class="info">

                                <?php echo esc_html__('Registered Domain:', 'qreatix'); ?>

                            </div>

                            <div class="value">

                                <!-- domain link -->
                                <a href="<?php echo esc_url($domain); ?>" class="domain">

                                    <?php echo esc_html($domain); ?>

                                </a>

                            </div>

                        </li>

                    <?php endif; ?>

                    <!-- info item -->
                    <li class="info-item">

                        <!-- info -->
                        <div class="info">

                            <?php echo esc_html__('Activations Left:', 'qreatix'); ?>

                        </div>

                        <!-- value -->
                        <div class="value">

                            <?php echo esc_html($activations_left) . esc_html__(' Activations', 'qreatix'); ?>

                        </div>

                    </li>

                    <?php if (!empty($last_check)): ?>

                        <li class="info-item">

                            <!-- info -->
                            <div class="info">

                                <?php echo esc_html__('Last Check:', 'qreatix'); ?>

                            </div>

                            <!-- value -->
                            <div class="value">

                                <?php echo esc_html($last_check->format('F j, Y, g:i a')); ?>

                            </div>

                        </li>

                    <?php endif; ?>

                </ul>

            </div>

        <?php

        endif;

    }

    /**
     * @return void
     */
    public function changelog_tab()
    {

        /* changelog data */
        $changelog = get_option($this->getInstance()->slug . '_meta');

        /* check all req changelog data */
        if (!empty($changelog)
            && !empty($changelog['name'])
            && !empty($changelog['slug'])
            && !empty($changelog['changelog']['versions'])):

            /* changelog main data */
            $log = $changelog['changelog'];

            /* versions list */
            $versions = $log['versions'];

            /* check if versions is not empty */
            if (!empty($versions)):

                /* sort versions by date */
                usort($versions, '\jkdevkit\Helper::compare_by_time_stamp');

                /* reverse versions for correct ordering */
                $versions = array_reverse($versions);

                /* changelog update */
                $changelog_update = get_option($this->getInstance()->slug . '_meta_update');

                /* check if changelog update is not empty */
                if (!empty($changelog_update)):

                    /* update date */
                    $update_date = $changelog_update->format('F j, Y, g:i a');

                endif;

                ?>

                <!-- changelog wrapper -->
                <div class="changelog">

                    <p class="last-changelog-update">

                           <span class="prefix">

                                <?php echo esc_html__('Last Update: ', 'qreatix'); ?>

                           </span>

                        <span class="date">

                                <?php if (!empty($update_date)): ?>

                                    <?php echo esc_html($update_date); ?>

                                <?php else: ?>

                                    <?php echo esc_html__('No Update', 'qreatix'); ?>

                                <?php endif; ?>

                            </span>

                    </p>

                    <!-- changelog list -->
                    <ul class="log-list">

                        <?php

                        /* versions loop */
                        foreach ($versions as $version):

                            /* version date */
                            $date = $version['date'];

                            /* version tag */
                            $tag = $version['version'];

                            /* version content (log) */
                            $log = $version['log'];

                            if (!empty($log)):

                                ?>

                                <!-- log item -->
                                <li class="log-item">

                                    <span class="dot"></span>

                                    <?php if (!empty($tag) || !empty($date)): ?>

                                        <!-- version info -->
                                        <div class="version-info">

                                            <?php if (!empty($tag)): ?>

                                                <!-- version tag -->
                                                <span class="tag">

                                                        <?php echo esc_html($tag); ?>

                                                    </span>

                                            <?php endif; ?>

                                            <!-- version divider -->
                                            <span class="divider">

                                                    <?php echo esc_html__('published at', 'qreatix'); ?>

                                                </span>

                                            <?php if (!empty($date)): ?>

                                                <span class="date">

                                                        <?php echo esc_html($date); ?>

                                                    </span>

                                            <?php endif; ?>

                                        </div>

                                    <?php endif; ?>

                                    <!-- changes list -->
                                    <ul class="changes-list">

                                        <?php foreach ($log as $log_item): ?>

                                            <?php if (!empty($log_item['type']) || !empty($log_item['value'])): ?>

                                                <!-- change item -->
                                                <li class="change-item">

                                                    <?php if (!empty($log_item['type'])): ?>

                                                        <!-- change type label -->
                                                        <p class="change-type-label <?php echo esc_attr($log_item['type']); ?>">

                                                            <?php echo esc_html($log_item['type']); ?>

                                                        </p>

                                                    <?php endif; ?>

                                                    <?php if (!empty($log_item['value'])): ?>

                                                        <!-- change value -->
                                                        <p class="value">

                                                            <?php echo esc_html($log_item['value'] . ';'); ?>

                                                        </p>

                                                    <?php endif; ?>

                                                </li>

                                            <?php endif; ?>

                                        <?php endforeach; ?>

                                    </ul>

                                </li>

                            <?php endif; ?>

                        <?php endforeach; ?>

                    </ul>

                </div>

            <?php

            endif;

        else:

            /* no changelog warning alert */
            Helper::add_alert(array(
                'slug' => 'no-changelog',
                'type' => 'warning',
                'title' => esc_html__('Unfortunately, there is no changelog for this item yet.', 'qreatix'),
                'description' => esc_html__('If you see this message, then most likely the changelog has not been created yet.', 'qreatix'),
                'icon' => 'ri-git-branch-line',
            ));

        endif;

    }

    /**
     * @return void
     */
    public function shell_settings_tab()
    {

        ?>

        <div class="settings-wrapper shell-settings">

            <div class="settings-side">

                <?php

                /* Shell Color Scheme */
                Controls_Manager::add_setting(array(
                    'type' => 'button_group',
                    'slug' => 'jkd-shell-color-scheme',
                    'label' => esc_html__('Color Scheme', 'qreatix'),
                    'description' => esc_html__('Select the shell color scheme.', 'qreatix'),
                    'options' => array(
                        'light' => esc_html__('Light', 'qreatix'),
                        'dark' => esc_html__('Dark', 'qreatix'),
                    ),
                    'default' => 'light',
                    'cookie' => 'jkd-shell-cs'
                ));

                /* Shell View */
                Controls_Manager::add_setting(array(
                    'type' => 'button_group',
                    'slug' => 'jkd-shell-view',
                    'label' => esc_html__('Shell View', 'qreatix'),
                    'description' => esc_html__('Select the shell view mode.', 'qreatix'),
                    'options' => array(
                        'minimal' => esc_html__('Minimal', 'qreatix'),
                        'large' => esc_html__('Large', 'qreatix'),
                    ),
                    'default' => 'minimal',
                    'cookie' => 'jkd-shell-view'
                ));

                ?>

            </div>

        </div>

        <?php

    }

    /**
     * @return void
     */
    public function fonts_tab()
    {

        /* fonts library */
        $fonts_library = \jkdevkit\Fonts_Manager::get_fonts_library();

        ?>

        <!-- FONTS TAB WRAPPER START -->

        <div class="fonts-tab-wrapper">

            <!-- FONTS SETTINGS START -->

            <div class="settings-wrapper fonts-settings">

                <!-- SETTINGS SIDE START -->

                <div class="settings-side">

                    <?php

                    /* Credentials */
                    Controls_Manager::add_setting(array(
                        'type' => 'divider',
                        'slug' => 'section-fonts-credentials',
                        'label' => esc_html__('Credentials', 'qreatix'),
                    ));

                    /* Google API Key */
                    Controls_Manager::add_setting(array(
                        'type' => 'password',
                        'slug' => 'google-api-key',
                        'label' => esc_html__('Google API Key', 'qreatix'),
                        'description' => esc_html__('Enter your Google API Key. ', 'qreatix'),
                        'placeholder' => esc_html('xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx'),
                    ));

                    /* Typekit API Token */
                    Controls_Manager::add_setting(array(
                        'type' => 'password',
                        'slug' => 'typekit-api-token',
                        'label' => esc_html__('Typekit API Token', 'qreatix'),
                        'description' => esc_html__('Enter your Typekit API Token. ', 'qreatix'),
                        'placeholder' => esc_html('xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx'),
                    ));

                    /* General */
                    Controls_Manager::add_setting(array(
                        'type' => 'divider',
                        'slug' => 'section-fonts-general',
                        'label' => esc_html__('General', 'qreatix'),
                    ));

                    /* Cache Requests */
                    Controls_Manager::add_setting(array(
                        'type' => 'toggle',
                        'slug' => 'fonts-cache-requests',
                        'label' => esc_html__('Cache Requests', 'qreatix'),
                        'description' => esc_html__('If true - API requests will be locally cached in the Database (Recommended).', 'qreatix'),
                        'default' => 'yes',
                    ));

                    /* Cache Fonts */
                    Controls_Manager::add_setting(array(
                        'type' => 'toggle',
                        'slug' => 'fonts-cache-fonts',
                        'label' => esc_html__('Cache Fonts', 'qreatix'),
                        'description' => esc_html__('If true - fonts will be locally cached in the uploads folder (Recommended).', 'qreatix'),
                        'default' => 'yes',
                    ));

                    /* Font Connection */
                    Controls_Manager::add_setting(array(
                        'type' => 'button_group',
                        'slug' => 'fonts-font-connection',
                        'label' => esc_html__('Font Connection', 'qreatix'),
                        'description' => esc_html__('Select the font connection.', 'qreatix'),
                        'options' => array(
                            'inline' => esc_html__('Inline', 'qreatix'),
                            'file' => esc_html__('File', 'qreatix'),
                        ),
                        'default' => 'inline',
                    ));

                    /*

                    TODO make this real

                     Controls_Manager::add_setting(array(
                        'type' => 'checkbox_group',
                        'slug' => 'fonts-integrations',
                        'label' => esc_html__('Integrations', 'qreatix'),
                        'description' => esc_html__('Choose support for third-party builders/plugins.', 'qreatix'),
                        'options' => array(
                            'kirki' => esc_html__('Kirki', 'qreatix'),
                            'elementor' => esc_html__('Elementor', 'qreatix'),
                            'oxygen' => esc_html__('Oxygen Builder', 'qreatix'),
                            'beaver' => esc_html__('Beaver Builder', 'qreatix'),
                            'divi' => esc_html__('Divi Builder', 'qreatix'),
                            'wpbakery' => esc_html__('WPBakery', 'qreatix'),
                            'vc' => esc_html__('Visual Composer', 'qreatix'),
                        ),
                    ));

                     * */

                    /* Fonts Library */
                    Controls_Manager::add_setting(array(
                        'type' => 'divider',
                        'slug' => 'section-fonts-library',
                        'label' => esc_html__('Fonts Library', 'qreatix'),
                    ));

                    ?>

                    <div class="setting-part fonts-manager">

                        <h6 class="setting-title">

                            <?php echo esc_html__('Add font to the library', 'qreatix'); ?>

                        </h6>

                        <p class="setting-description">

                            <?php echo esc_html__('You can add fonts here using Google Fonts, Typekit, or using any custom files.', 'qreatix'); ?>

                        </p>

                        <div class="buttons-wrapper">

                            <button class="jkd-button adding-font-button google-font-button jkd-button google-style size-ui animation-fade"
                                    data-type="google">

                                    <span class="static-text">

                                          <?php echo esc_html__('Google Font +', 'qreatix'); ?>

                                    </span>

                                <span class="loading-text">

                                        <?php echo esc_html__('Loading', 'qreatix'); ?>

                                        <?php Helper::loader_render(); ?>

                                    </span>

                                <span class="cancel-text">

                                        <?php echo esc_html__('Cancel', 'qreatix'); ?>

                                        <i class="ri-close-line right-icon"></i>

                                    </span>

                            </button>

                            <button class="jkd-button adding-font-button typekit-font-button jkd-button typekit-style size-ui animation-fade"
                                    data-type="typekit">

                                    <span class="static-text">

                                          <?php echo esc_html__('Typekit Font +', 'qreatix'); ?>

                                    </span>

                                <span class="loading-text">

                                        <?php echo esc_html__('Loading', 'qreatix'); ?>

                                        <?php Helper::loader_render(); ?>

                                    </span>

                                <span class="cancel-text">

                                        <?php echo esc_html__('Cancel', 'qreatix'); ?>

                                        <i class="ri-close-line right-icon"></i>

                                    </span>

                            </button>

                            <button class="jkd-button adding-font-button custom-font-button jkd-button wp-style size-ui animation-fade"
                                    data-type="custom">

                                    <span class="static-text">

                                          <?php echo esc_html__('Custom Font +', 'qreatix'); ?>

                                    </span>

                                <span class="loading-text">

                                        <?php echo esc_html__('Loading', 'qreatix'); ?>

                                        <?php Helper::loader_render(); ?>

                                    </span>

                                <span class="cancel-text">

                                        <?php echo esc_html__('Cancel', 'qreatix'); ?>

                                        <i class="ri-close-line right-icon"></i>

                                    </span>

                            </button>

                        </div>

                        <div class="add-new-font-form">

                            <div class="form-loader-wrapper">

                                <?php Helper::loader_render(); ?>

                            </div>

                            <div class="form-inner">

                            </div>

                        </div>

                        <h6 class="setting-title">

                            <?php echo esc_html__('Fonts Library', 'qreatix'); ?>

                        </h6>

                        <p class="setting-description">

                            <?php echo esc_html__('Here are all your added fonts.', 'qreatix'); ?>

                        </p>

                        <ul class="fonts-library <?php if (empty($fonts_library)): ?>empty<?php endif; ?>">

                            <?php if (!empty($fonts_library)): ?>

                                <?php foreach ($fonts_library as $font):

                                    \jkdevkit\Fonts_Manager::font_item_render($font);

                                endforeach; ?>

                            <?php else: ?>

                                <li class="jkd-notice small warning">

                                    <i class="ri-archive-line notice-icon"></i>

                                    <p class="notice-text">

                                        <?php echo esc_html__('You have not added any fonts yet', 'qreatix'); ?>

                                    </p>

                                </li>

                            <?php endif; ?>

                        </ul>

                        <!-- edit font overlay -->
                        <div class="edit-font-overlay">

                            <?php Helper::loader_render(); ?>

                            <div class="popup-wrapper">


                            </div>

                        </div>

                    </div>

                </div>

                <!-- SETTINGS SIDE END -->

            </div>

            <!-- FONTS SETTINGS END -->

        </div>

        <!-- FONTS TAB WRAPPER END -->

        <?php

    }

}
