<?php
/*
 *
 */

/**
 * Single Product Image
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/single-product/product-image.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce\Templates
 * @version 3.5.1
 */

defined('ABSPATH') || exit;

// Note: `wc_get_gallery_image_html` was added in WC 3.3.2 and did not exist prior. This check protects against theme overrides being used on older versions of WC.
if (!function_exists('wc_get_gallery_image_html')) {
    return;
}

global $product;

$columns = apply_filters('woocommerce_product_thumbnails_columns', 4);
$post_thumbnail_id = $product->get_image_id();
$wrapper_classes = apply_filters(
    'woocommerce_single_product_image_gallery_classes',
    array(
        'woocommerce-product-gallery',
        'woocommerce-product-gallery--' . ($post_thumbnail_id ? 'with-images' : 'without-images'),
        'woocommerce-product-gallery--columns-' . absint($columns),
        'images',
    )
);

$attachment_ids = $product->get_gallery_image_ids();

$product_type = get_theme_mod('shop-single-product-type', esc_attr('default'));

$image_ratio = get_theme_mod('shop-image-ratio', 'square');

if (!empty($_GET['product_type'])):

    $product_type = $_GET['product_type'];

endif;

$zoom_toggle = get_theme_mod('shop-product-zoom-toggle', esc_attr(1));

if (!empty($_GET['zoom'])):

    $zoom_toggle = $_GET['zoom'];

endif;

if (!empty($_GET['zoom']) && $_GET['zoom'] === 'false'):

    $zoom_toggle = false;

endif;

?>
<div class="<?php echo esc_attr(implode(' ', array_map('sanitize_html_class', $wrapper_classes))); ?>"
     data-columns="<?php echo esc_attr($columns); ?>" style="opacity: 0; transition: opacity .25s ease-in-out;">
    <figure class="woocommerce-product-gallery__wrapper">

        <?php

        if (class_exists('JKD_Helper')):

            $video_gallery = JKD_Helper::get_field('field_product_video_gallery', $product->get_id());

            if (!empty($video_gallery)):

                wp_enqueue_script(JKD_Core::$prefix . 'plyr');

                wp_enqueue_style(JKD_Core::$prefix . 'plyr');

                foreach ($video_gallery as $item):

                    $field_product_video_index = (int)$item['option_product_video_index'];

                    array_splice($attachment_ids, $field_product_video_index, 0, array($item));

                endforeach;

            endif;

        endif;

        if (!empty($attachment_ids)):

            array_push($attachment_ids, $post_thumbnail_id);

            $attachment_ids = array_reverse($attachment_ids);

            ?>

            <div class="thumbnails-slider-wrapper">

                <?php if (count($attachment_ids) > 4): ?>

                    <div class="navigation-button navigation-button-prev">

                        <i class="ri-arrow-up-line"></i>

                    </div>

                <?php endif; ?>

                <div class="swiper-container products-thumbnails-slider"
                     <?php if ($product_type === 'default'): ?>data-direction="vertical" data-space="15"
                     <?php elseif ($product_type === 'two-side'): ?>data-direction="horizontal"
                     data-space="0"<?php endif; ?>>

                    <div class="swiper-wrapper">

                        <?php

                        if ($attachment_ids && $product->get_image_id()) {
                            foreach ($attachment_ids as $attachment_id) {

                                if (is_array($attachment_id)):

                                    $preview_id = $attachment_id['option_product_video_preview']['ID'];

                                    ?>

                                    <div class="swiper-slide">

                                        <i class="ri-play-line play-icon"></i>

                                        <?php

                                        if (class_exists('JKD_Helper')):

                                            echo JKD_Theme::render_image($preview_id,
                                                'jk-square-size-extra-small');

                                        else:

                                            ?>

                                            <img src="<?php echo esc_url(wp_get_attachment_image_url($preview_id, 'medium')); ?>"
                                                 alt="<?php echo esc_attr(get_the_title()); ?>">

                                        <?php

                                        endif;

                                        ?>

                                    </div>

                                <?php

                                else:

                                    ?>

                                    <div class="swiper-slide">

                                        <?php

                                        if (class_exists('JKD_Helper')):

                                            echo JKD_Theme::render_image($attachment_id,
                                                'jk-square-size-extra-small');

                                        else:

                                            ?>

                                            <img src="<?php echo esc_url(wp_get_attachment_image_url($attachment_id, 'large')); ?>"
                                                 alt="<?php echo esc_attr(get_the_title()); ?>">

                                        <?php

                                        endif;

                                        ?>

                                    </div>

                                <?php

                                endif;

                            }
                        }

                        ?>

                    </div>

                </div>

                <?php if (count($attachment_ids) > 4): ?>

                    <div class="navigation-button navigation-button-next">

                        <i class="ri-arrow-down-line"></i>

                    </div>

                <?php endif; ?>

            </div>

        <?php endif; ?>

        <?php if (!empty($attachment_ids)): ?>

            <div class="image-wrapper ">

                <div class="swiper-container products-gallery-slider">

                    <div class="swiper-wrapper">

                        <?php

                        if ($attachment_ids && $product->get_image_id()) {
                            foreach ($attachment_ids as $attachment_id) {

                                if (is_array($attachment_id)):

                                    $preview_id = $attachment_id['option_product_video_preview']['ID'];

                                    $option_product_video_index = $attachment_id['option_product_video_index'];

                                    $option_product_video = $attachment_id['option_product_video'];

                                    if ($option_product_video === 'html'):

                                        $option_product_video_file = $attachment_id['option_product_video_file'];

                                    else:

                                        $option_product_video_url = $attachment_id['option_product_video_url'];

                                    endif;

                                    ?>

                                    <div class="swiper-slide">

                                        <?php

                                        if ($product_type === 'default'):

                                            if ($image_ratio === 'square'):

                                                echo JKD_Theme::render_image($preview_id,
                                                    'jk-square-size-medium');

                                            elseif ($image_ratio === 'vertical'):

                                                echo JKD_Theme::render_image($preview_id,
                                                    'jk-vertical-size-large');

                                            endif;

                                        elseif ($product_type === 'two-side'):

                                            if ($image_ratio === 'square'):

                                                echo JKD_Theme::render_image($preview_id,
                                                    'jk-square-size-extra-large');

                                            elseif ($image_ratio === 'vertical'):

                                                echo JKD_Theme::render_image($preview_id,
                                                    'jk-vertical-size-extra-large');

                                            endif;

                                        endif;

                                        ?>

                                        <div class="video-wrapper">

                                            <?php

                                            if ($option_product_video === 'html'):

                                                if (!empty($option_product_video_file)):

                                                    ?>

                                                    <video class="video-player player" playsinline controls
                                                           data-poster="<?php echo esc_url(wp_get_attachment_image_url($preview_id, 'large')); ?>">

                                                        <source src="<?php echo esc_url($option_product_video_file); ?>"
                                                                type="video/mp4"/>

                                                    </video>

                                                <?php

                                                endif;

                                            elseif ($option_product_video === 'youtube'):

                                                if (!empty($option_product_video_url)):

                                                    ?>

                                                    <div class="plyr__video-embed video-player player">

                                                        <iframe src="<?php echo esc_url($option_product_video_url); ?>&amp;iv_load_policy=3&amp;modestbranding=0&amp;playsinline=0&amp;showinfo=0&amp;rel=0&amp;enablejsapi=1"
                                                                allowfullscreen
                                                                allowtransparency
                                                                allow="autoplay">

                                                        </iframe>

                                                    </div>

                                                <?php

                                                endif;

                                            elseif ($option_product_video === 'vimeo'):

                                                if (!empty($option_product_video_url)):

                                                    ?>

                                                    <div class="plyr__video-embed video-player player">

                                                        <iframe src="<?php echo esc_url($option_product_video_url); ?>&amp;byline=false&amp;portrait=false&amp;title=false&amp;speed=true&amp;transparent=0&amp;gesture=media">

                                                        </iframe>

                                                    </div>

                                                <?php

                                                endif;

                                            endif;

                                            ?>

                                        </div>

                                    </div>

                                <?php

                                else:

                                    ?>

                                    <div class="swiper-slide">

                                        <?php if ($zoom_toggle): ?>

                                        <div class="zoom-wrapper"
                                             data-zoom-value="2"
                                            <?php if ($product_type === 'default'): ?>
                                                data-zoom-url="<?php echo esc_url(wp_get_attachment_image_url($attachment_id, 'jk-square-size-medium')); ?>" <?php elseif ($product_type === 'two-side'): ?>data-zoom-url="<?php echo esc_url(wp_get_attachment_image_url($attachment_id, 'jk-square-size-extra-large')); ?>"
                                            <?php endif; ?>>

                                            <?php

                                            endif;

                                            if (class_exists('JKD_Helper')):

                                                if ($product_type === 'default'):

                                                    if ($image_ratio === 'square'):

                                                        echo JKD_Theme::render_image($attachment_id,
                                                            'jk-square-size-medium');

                                                    elseif ($image_ratio === 'vertical'):

                                                        echo JKD_Theme::render_image($attachment_id,
                                                            'jk-vertical-size-large');

                                                    endif;

                                                elseif ($product_type === 'two-side'):

                                                    if ($image_ratio === 'square'):

                                                        echo JKD_Theme::render_image($attachment_id,
                                                            'jk-wide-size-extra-large');

                                                    elseif ($image_ratio === 'vertical'):

                                                        echo JKD_Theme::render_image($attachment_id,
                                                            'jk-wide-size-extra-large');

                                                    endif;

                                                endif;

                                            else:

                                                ?>

                                                <img src="<?php echo esc_url(wp_get_attachment_image_url($attachment_id, 'large')); ?>"
                                                     alt="<?php echo esc_attr(get_the_title()); ?>">

                                            <?php

                                            endif;

                                            if ($zoom_toggle):

                                            ?>

                                        </div>

                                    <?php endif; ?>

                                    </div>

                                <?php

                                endif;

                            }
                        }

                        ?>

                    </div>

                    <div class="pagination-numbers">

                    </div>

                </div>

            </div>

        <?php

        else:

            ?>

            <div class="image-wrapper">

                <div class="zoom-wrapper"
                     data-zoom-value="2"
                     data-zoom-url="<?php echo esc_url(wp_get_attachment_image_url($post_thumbnail_id, 'jk-square-size-large')); ?>">

                    <?php

                    if (class_exists('JKD_Helper')):

                        if ($image_ratio === 'square'):

                            echo JKD_Theme::render_image($post_thumbnail_id,
                                'jk-square-size-medium');

                        elseif ($image_ratio === 'vertical'):

                            echo JKD_Theme::render_image($post_thumbnail_id,
                                'jk-vertical-size-large');

                        endif;

                    else:

                        ?>

                        <img src="<?php echo esc_url(wp_get_attachment_image_url($post_thumbnail_id, 'large')); ?>"
                             alt="<?php echo esc_attr(get_the_title()); ?>">

                    <?php

                    endif;

                    ?>

                </div>

            </div>

        <?php

        endif;

        ?>

    </figure>
</div>
